/******************************************************************************
* Includes
*******************************************************************************/

#include <stdint.h>
#include "6dof_hal.h"
#include "6dof_hw.h"

/******************************************************************************
* Module Preprocessor Constants
*******************************************************************************/

/******************************************************************************
* Module Preprocessor Macros
*******************************************************************************/

/******************************************************************************
* Module Typedefs
*******************************************************************************/

/******************************************************************************
* Module Variable Definitions
*******************************************************************************/

/******************************************************************************
* Function Prototypes
*******************************************************************************/
static inline uint8_t get_bit (uint8_t reg_num, uint8_t bit_num)
{
  uint8_t temp = 0;
  dof6_hal_read(&reg_num, &temp, 1);
  temp = temp >> bit_num;
  temp &= 1;
  return temp;
}

static inline clear_bit (uint8_t reg_num, uint8_t bit_num)
{
  uint8_t temp = 0;

  dof6_hal_read(&reg_num, &temp, 1);
  temp &= ~(1 << bit_num);
  dof6_hal_write(&reg_num, &temp, 1);
}

static inline set_bit (uint8_t reg_num, uint8_t bit_num)
{
  uint8_t temp = 0;

  dof6_hal_read(&reg_num, &temp, 1);
  temp |= (1 << bit_num);
  dof6_hal_write(&reg_num, &temp, 1);
}


static inline int16_t get_data(uint8_t adress)
{


  int16_t temp = 0;
  int16_t tempdata = 0;
  uint8_t buffer[2];
  dof6_hal_read(&adress , buffer, 2);
  temp |= (int16_t)buffer[0];
  temp |= ((int16_t)buffer[1]) << 8;

  return temp;

}

static inline uint16_t get_unsinged_data(uint8_t adress)
{


  uint16_t temp = 0;
  uint8_t buffer[2];
  dof6_hal_read(&adress , buffer, 2);

  temp += (int16_t) buffer[0];

  temp |= ((int16_t) buffer[1]) << 8;


  return temp;

}



/******************************************************************************
* Function Definitions
*******************************************************************************/

int8_t dof6_init ( uint8_t address )
{
  uint8_t adress = 0x1B;
  uint8_t temp;
  dof6_hal_init ( address );


  dof6_hal_read(&adress, &temp, 1);
  if (temp != 0x01) return -1;

  return 0;
}

////////////////////////////////////////////////////////////////////////////////

int8_t dof6_get_chip_id()
{
  uint8_t adress = CHIP_ID;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  return temp;
}

////////////////////////////////////////////////////////////////////////////////

int8_t dof6_fatal_error_detected()
{
  return get_bit(ERR_REG, 0);
}

uint8_t dof6_drop_cmd_err() {
  return get_bit(ERR_REG, 6);


}

int8_t dof6_error_detected() {
  uint8_t adress = ERR_REG;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  if (((temp >> 1) & 0x0F) == 0) return 0;                                  // no error
  else if (((temp >> 1) & 0x0F) == 1)   return 1;               //error
  else if (((temp >> 1) & 0x0F) == 2)   return 2;                           //error
  else if (((temp >> 1) & 0x0F) == 3)   return 3;                           //low-power  mode  and  interrupt  uses pre-filtered data
  else if (((temp >> 1) & 0x0F) == 6)   return 4;                           // ODRs  of  enabled  sensors  in  header-less mode do not match
  else if (((temp >> 1) & 0x0F) == 7)   return 5;                           //pre-filtered  data are  used  in  low  powermode
  else return -1;                                                           //reserved
}

////////////////////////////////////////////////////////////////////////////////

int8_t dof6_acc_power_mode_status()
{
  uint8_t adress = PMU_STATUS;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 4;
  temp &= 3;
  if (temp  == 1) return 0;                                                          //normal
  if (temp  == 0) return -1;                                                         //suspended
  if (temp  == 2) return 1;                                                          //low power
  return 0;
}

int8_t dof6_gyr_power_mode_status()
{
  uint8_t adress = PMU_STATUS;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 2;
  temp &= 3;
  if (temp == 1) return 0;                                                         //normal
  if (temp  == 0) return -1;                                                        //suspended
  if (temp == 2) return 1;                                                         //reserved
  if (temp == 3) return 2;                                                         //fast strat-up
}


int8_t dof6_mag_power_mode_status()
{
  uint8_t adress = PMU_STATUS;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 3;
  if (temp  == 1) return 0;                                                          //normal
  if (temp  == 0) return -1;                                                        //suspended
  if (temp  == 2) return 1;                                                         //low power
  return 0;
}

////////////////////////////////////////////////////////////////////////////////

int16_t dof6_get_mag_x()
{
  return get_data(DATA_0);
}

int16_t dof6_get_mag_y()
{
  return get_data(DATA_2);
}

int16_t dof6_get_mag_z()
{
  return get_data(DATA_4);
}

int16_t dof6_get_rhall()
{
  return get_data(DATA_6);
}

float dof6_get_gyr_x()
{
  int16_t temp_data;
  float temp;
  temp_data = get_data(DATA_8);
  if (dof6_get_gyr_range() == 125)
  {
    temp = temp_data / 262.4;
    return temp;
  }
  if (dof6_get_gyr_range() == 250)
  {
    temp = temp_data / 131.2;
    return temp;
  }
  if (dof6_get_gyr_range() == 500)
  {
    temp = temp_data / 65.6;
    return temp;
  }
  if (dof6_get_gyr_range() == 1000)
  {
    temp = temp_data / 32.8;
    return temp;
  }
  if (dof6_get_gyr_range() == 2000)
  {
    temp = temp_data / 16.4;
    return temp;
  }
}

float dof6_get_gyr_y()
{
  int16_t temp_data;
  float temp;
  temp_data = get_data(DATA_10);
  if (dof6_get_gyr_range() == 125)
  {
    temp = temp_data / 262.4;
    return temp;
  }
  if (dof6_get_gyr_range() == 250)
  {
    temp = temp_data / 131.2;
    return temp;
  }
  if (dof6_get_gyr_range() == 500)
  {
    temp = temp_data / 65.6;
    return temp;
  }
  if (dof6_get_gyr_range() == 1000)
  {
    temp = temp_data / 32.8;
    return temp;
  }
  if (dof6_get_gyr_range() == 2000)
  {
    temp = temp_data / 16.4;
    return temp;
  }
}

float dof6_get_gyr_z()
{
  int16_t temp_data;
  float temp;
  temp_data = get_data(DATA_12);
  if (dof6_get_gyr_range() == 125)
  {
    temp = temp_data / 262.4;
    return temp;
  }
  if (dof6_get_gyr_range() == 250)
  {
    temp = temp_data / 131.2;
    return temp;
  }
  if (dof6_get_gyr_range() == 500)
  {
    temp = temp_data / 65.6;
    return temp;
  }
  if (dof6_get_gyr_range() == 1000)
  {
    temp = temp_data / 32.8;
    return temp;
  }
  if (dof6_get_gyr_range() == 2000)
  {
    temp = temp_data / 16.4;
    return temp;
  }
}

float dof6_get_acc_x()
{
  int16_t temp_data;
  float temp;
  temp_data = get_data(DATA_14);
  if (dof6_get_acc_g_range() == 2)
  {
    temp = (float)temp_data / 16368;
    return temp;
  }
  if (dof6_get_acc_g_range() == 4)
  {
    temp = (float)temp_data / 8192;
    return temp;
  }
  if (dof6_get_acc_g_range() == 8)
  {
    temp = (float)temp_data / 4096;
    return temp;
  }
  if (dof6_get_acc_g_range() == 16)
  {
    temp = (float)temp_data / 2048;
    return temp;
  }
}

float dof6_get_acc_y()
{
  int16_t temp_data;
  float temp;
  temp_data = get_data(DATA_16);
  if (dof6_get_acc_g_range() == 2)
  {
    temp = (float)temp_data / 16368;
    return temp;
  }
  if (dof6_get_acc_g_range() == 4)
  {
    temp = (float)temp_data / 8192;
    return temp;
  }
  if (dof6_get_acc_g_range() == 8)
  {
    temp = (float)temp_data / 4096;
    return temp;
  }
  if (dof6_get_acc_g_range() == 16)
  {
    temp = (float)temp_data / 2048;
    return temp;
  }
}
float dof6_get_acc_z()
{
  int16_t temp_data;
  float temp;
  temp_data = get_data(DATA_18);
  if (dof6_get_acc_g_range() == 2)
  {
    temp = (float)temp_data / 16368;
    return temp;
  }
  if (dof6_get_acc_g_range() == 4)
  {
    temp = (float)temp_data / 8192;
    return temp;
  }
  if (dof6_get_acc_g_range() == 8)
  {
    temp = (float)temp_data / 4096;
    return temp;
  }
  if (dof6_get_acc_g_range() == 16)
  {
    temp = (float)temp_data / 2048;
    return temp;
  }
}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_sensortime()
{
  uint8_t adress = SENSORTIME_0;
  uint32_t  temp = 0;
  float t = 0;
  uint8_t buffer[3];
  dof6_hal_read(&adress, buffer, 3);
  temp += (uint32_t) buffer[0];
  temp |= ((uint16_t) buffer[1]) << 8;
  temp |= ((uint16_t) buffer[2]) << 16;
  t = temp * 0.039;
  return t;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_data_ready_acc()
{
  return get_bit(STATUS, 7);

}


uint8_t dof6_data_ready_gyr()
{
  return get_bit(STATUS, 6);

}
uint8_t dof6_data_ready_mag()
{
  return get_bit(STATUS, 5);

}
uint8_t dof6_data_ready_nvm()
{
  return get_bit(STATUS, 4);

}

uint8_t dof6_data_ready_foc()
{
  return get_bit(STATUS, 3);

}

uint8_t mag_man_op ()
{
  return get_bit(STATUS, 2);

}

uint8_t gyr_self_test_ok () {
  return get_bit(STATUS, 1);
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_step_int()
{
  return get_bit(INT_STATUS_0, 0);
}

uint8_t dof6_get_sigmot_int()
{
  return get_bit(INT_STATUS_0, 1);
}

uint8_t dof6_get_anym_int()
{
  return get_bit(INT_STATUS_0, 2);
}

uint8_t dof6_get_pmu_trigger_int()
{
  return get_bit(INT_STATUS_0, 3);
}

uint8_t dof6_get_d_tap_int()
{
  return get_bit(INT_STATUS_0, 4);
}

uint8_t dof6_get_s_tap_int()
{
  return get_bit(INT_STATUS_0, 5);
}

uint8_t dof6_get_orient_int()
{
  return get_bit(INT_STATUS_0, 6);
}

uint8_t dof6_get_flat_int()
{
  return get_bit(INT_STATUS_0, 7);
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_highg_int()
{
  return get_bit(INT_STATUS_1, 2);
}

uint8_t dof6_get_lowg_int()
{
  return get_bit(INT_STATUS_1, 3);
}

uint8_t dof6_get_drdy_int()
{
  return get_bit(INT_STATUS_1, 4);
}

uint8_t dof6_get_ffull_int()
{
  return get_bit(INT_STATUS_1, 5);
}

uint8_t dof6_get_fwm_int()
{
  return get_bit(INT_STATUS_1, 6);
}

uint8_t dof6_get_nomo_int()
{
  return get_bit(INT_STATUS_1, 7);
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_anym_first_x()
{
  return get_bit(INT_STATUS_2, 0);
}

uint8_t dof6_get_anym_first_y()
{
  return get_bit(INT_STATUS_2, 1);
}

uint8_t dof6_get_anym_first_z()
{
  return get_bit(INT_STATUS_2, 2);
}

uint8_t dof6_get_anym_sign()
{
  return get_bit(INT_STATUS_2, 3);
}

uint8_t dof6_get_tap_first_x()
{
  return get_bit(INT_STATUS_2, 4);
}

uint8_t dof6_get_tap_first_y()
{
  return get_bit(INT_STATUS_2, 5);
}

uint8_t dof6_get_tap_first_z()
{
  return get_bit(INT_STATUS_2, 6);
}

uint8_t dof6_get_tap_sign()
{
  return get_bit(INT_STATUS_2, 7);
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_high_first_x()
{
  return get_bit(INT_STATUS_3, 0);
}

uint8_t dof6_get_high_first_y()
{
  return get_bit(INT_STATUS_3, 1);
}

uint8_t dof6_get_high_first_z()
{
  return get_bit(INT_STATUS_3, 2);
}

uint8_t dof6_get_high_sign()
{
  return get_bit(INT_STATUS_3, 3);
}

uint8_t dof6_get_orient()
{
  uint8_t adress = INT_STATUS_3;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 4;
  temp &= 3;
  return temp;
}


uint8_t dof6_get_orient_2()
{
  return get_bit(INT_STATUS_3, 6);
}

uint8_t dof6_get_flat()
{
  return get_bit(INT_STATUS_3, 7);
}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_sensor_temperature()
{
  float t = 0;
  uint16_t temp = 0;
  temp = get_unsinged_data(TEMPERATURE_0);
  if (temp >> 15 == 1)
  {
    temp = ~(temp) + 1;
    t = 23 - temp / pow(2, 9);
    return t;
  }
  t = 23 + temp / pow(2, 9);
  return t;
}

////////////////////////////////////////////////////////////////////////////////

uint16_t dof6_get_fifo_lenght()
{
  uint8_t adress = FIFO_LENGTH_0;
  uint16_t temp = 0;
  uint8_t buffer[2];
  dof6_hal_read(&adress, buffer, 2);
  temp += (uint16_t) buffer[0];
  buffer[1] = buffer[1] & 0x07;
  temp |= ((uint16_t) buffer[1]) << 8;
  return temp;
}

////////////////////////////////////////////////////////////////////////////////

uint16_t dof6_get_fifo_data()
{
  uint8_t adress = FIFO_DATA;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  return temp;

}

////////////////////////////////////////////////////////////////////////////////

void dof6_set_acc_undersampling(bool set)
{
  if (set)  set_bit(ACC_CONF, 7);
  else     clear_bit (ACC_CONF, 7);
}

uint8_t dof6_get_acc_undersampling()
{
  return get_bit(ACC_CONF, 7);
}

uint8_t dof6_get_acc_bandwidth()
{
  uint8_t adress = ACC_CONF;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x70;
  temp = temp >> 4;
  return temp;

}

int8_t dof6_set_acc_bandwidth(uint8_t bw)
{
  uint8_t status = 0;
  uint8_t adress = ACC_CONF;
  uint8_t temp;
  if (bw < 0 || bw > 7) return status = -1;
  bw = bw << 4;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x70);
  temp |= bw;
  dof6_hal_write(&adress, &temp, 1);
  return status;

}

float dof6_get_acc_output_data_rate()
{
  uint8_t adress = ACC_CONF;
  uint8_t temp;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x0F;
  t = 100 / (pow(2, 8 - temp));
  return t;
}

void dof6_set_acc_output_data_rate(acc_output_data_rate acc_odr)
{
  uint8_t adress = ACC_CONF;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  switch (acc_odr)
  {
  case HZ_0_78:
    temp &= ~(15);
    temp |= 1;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_1_56:
    temp &= ~(15);
    temp |= 2;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_3_125:
    temp &= ~(15);
    temp |= 3;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_6_25:
    temp &= ~(15);
    temp |= 4;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_12_5:
    temp &= ~(15);
    temp |= 5;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_25:
    temp &= ~(15);
    temp |= 6;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_50:
    temp &= ~(15);
    temp |= 7;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_100:
    temp &= ~(15);
    temp |= 8;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_200:
    temp &= ~(15);
    temp |= 9;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_400:
    temp &= ~(15);
    temp |= 10;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_800:
    temp &= ~(15);
    temp |= 11;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_1600:
    temp &= ~(15);
    temp |= 12;
    dof6_hal_write(&adress, &temp, 1);
    break;
  }
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_acc_g_range()
{
  uint8_t adress = ACC_RANGE;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x0F;
  if (temp == 3) return 2;
  if (temp == 5) return 4;
  if (temp == 8) return 8;
  if (temp == 12) return 16;
  return 2;
}

void  dof6_set_acc_g_range(acc_g_range acc_r)
{
  uint8_t adress = ACC_RANGE;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  switch (acc_r)
  {
  case G_2:
    temp &= ~(15);
    temp |= 3;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case G_4:
    temp &= ~(15);
    temp |= 5;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case G_8:
    temp &= ~(15);
    temp |= 8;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case G_16:
    temp &= ~(15);
    temp |= 12;
    dof6_hal_write(&adress, &temp, 1);
    break;
  }
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_gyr_bandwidth()
{
  uint8_t adress = GYR_CONF;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x30;
  temp = temp >> 4;
  return temp;

}


int8_t dof6_set_gyr_bandwidth(uint8_t bw)
{
  uint8_t status = 0;
  uint8_t temp;
  uint8_t adress = GYR_CONF;
  if (bw < 0 || bw > 3) return status = -1;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x30);
  bw = bw << 4;
  temp |= bw;
  dof6_hal_write(&adress, &temp, 1);
  return status;

}


float dof6_get_gyr_output_data_rate()
{
  uint8_t adress = GYR_CONF;
  uint8_t temp;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x0F;
  t = 100 / pow(2, 8 - temp);
  return t;
}

void dof6_set_gyr_output_data_rate(gyr_output_data_rate gyr_odr)
{
  uint8_t adress = GYR_CONF;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  switch (gyr_odr)
  {

  case HZ_25_G:
    temp &= ~(15);
    temp |= 6;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_50_G:
    temp &= ~(15);
    temp |= 7;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_100_G:
    temp &= ~(15);
    temp |= 8;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_200_G:
    temp &= ~(15);
    temp |= 9;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_400_G:
    temp &= ~(15);
    temp |= 10;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_800_G:
    temp &= ~(15);
    temp |= 11;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_1600_G:
    temp &= ~(15);
    temp |= 12;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HZ_3200_G:
    temp &= ~(15);
    temp |= 13;
    dof6_hal_write(&adress, &temp, 1);
    break;
  }
}

////////////////////////////////////////////////////////////////////////////////

uint32_t dof6_get_gyr_range()
{
  uint8_t adress = GYR_RANGE;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x07;
  if (temp == 0) return 2000;
  if (temp == 1) return 1000;
  if (temp == 2) return 500;
  if (temp == 3) return 250;
  if (temp == 4) return 125;
  return -1;

}

void  dof6_set_gyr_range(gyr_range gyr_r)
{
  uint8_t adress = GYR_RANGE;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  switch (gyr_r)
  {
  case ARR_2000:
    temp &= ~(7);
    temp |= 0;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case ARR_1000:
    temp &= ~(7);
    temp |= 1;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case ARR_500:
    temp &= ~(7);
    temp |= 2;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case ARR_250:
    temp &= ~(7);
    temp |= 3;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case ARR_120:
    temp &= ~(7);
    temp |= 4;
    dof6_hal_write(&adress, &temp, 1);
    break;
  }
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_mag_output_data_rate()
{
  uint8_t adress = MAG_CONF;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x0F;
  return temp;
}

void dof6_set_mag_output_data_rate(mag_output_data_rate mag_odr)
{
  uint8_t adress = MAG_CONF;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  switch (mag_odr)
  {

  case M_HZ_0_78:
    temp &= ~(15);
    temp |= 1;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case M_HZ_1_56:
    temp &= ~(15);
    temp |= 2;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case M_HZ_3_125:
    temp &= ~(15);
    temp |= 3;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case M_HZ_6_25:
    temp &= ~(15);
    temp |= 4;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case M_HZ_12_5:
    temp &= ~(15);
    temp |= 5;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case M_HZ_25:
    temp &= ~(15);
    temp |= 6;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case M_HZ_50:
    temp &= ~(15);
    temp |= 7;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case M_HZ_100:
    temp &= ~(15);
    temp |= 8;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case M_HZ_200:
    temp &= ~(15);
    temp |= 9;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case M_HZ_400:
    temp &= ~(15);
    temp |= 10;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case M_HZ_800:
    temp &= ~(15);
    temp |= 11;
    dof6_hal_write(&adress, &temp, 1);
    break;
  }
}

////////////////////////////////////////////////////////////////////////////////


uint8_t dof6_get_acc_fifo_filt_data()
{
  return get_bit(FIFO_DOWNS, 7);
}

void dof6_set_acc_fifo_filt_data(bool set)
{
  if (set)  set_bit(FIFO_DOWNS, 7);
  else     clear_bit (FIFO_DOWNS, 7);
}

uint16_t dof6_get_acc_fifo_downs ()
{
  uint16_t t;
  uint8_t adress = FIFO_DOWNS;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x70;
  temp = temp >> 4;
  t = pow(2, temp);
  return t;
}

void dof6_set_acc_fifo_downs (acc_fifo_downsapling_ratio acc_fdr)
{
  uint8_t adress = FIFO_DOWNS;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x70);
  switch (acc_fdr)
  {
  case AF_HZ_1:
    dof6_hal_write(&adress, &temp, 1);
    break;
  case AF_HZ_2:
    temp |= (1 << 4);
    dof6_hal_write(&adress, &temp, 1);
    break;
  case AF_HZ_4:
    temp |= (2 << 4);
    dof6_hal_write(&adress, &temp, 1);
    break;
  case AF_HZ_8:
    temp |= (3 << 4);
    dof6_hal_write(&adress, &temp, 1);
    break;
  case AF_HZ_16:
    temp |= (4 << 4);
    dof6_hal_write(&adress, &temp, 1);
    break;
  case AF_HZ_32:
    temp |= (5 << 4);
    dof6_hal_write(&adress, &temp, 1);
    break;
  case AF_HZ_64:
    temp |= (6 << 4) ;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case AF_HZ_128:
    temp |= (7 << 4) ;
    dof6_hal_write(&adress, &temp, 1);
    break;
  }
}

uint8_t dof6_get_gyr_fifo_filt_data()
{
  return get_bit(FIFO_DOWNS, 3);
}
void dof6_set_gyr_fifo_filt_data(bool set)
{
  if (set)  set_bit(FIFO_DOWNS, 0);
  else     clear_bit (FIFO_DOWNS, 0);
}

uint16_t dof6_get_gyr_fifo_downs ()
{
  uint16_t t;
  uint8_t adress = FIFO_DOWNS;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x07;
  t = pow(2, temp);
  return t;
}

void dof6_set_gyr_fifo_downs (gyr_fifo_downsapling_ratio gyr_fdr)
{
  uint8_t adress = FIFO_DOWNS;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(7);
  switch (gyr_fdr)
  {
  case GF_HZ_1:
    temp |= 0;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case GF_HZ_2:
    temp |= 1;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case GF_HZ_4:
    temp |= 2;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case GF_HZ_8:
    temp |= 3;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case GF_HZ_16:
    temp |= 4;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case GF_HZ_32:
    temp |= 5;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case GF_HZ_64:
    temp |= 6;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case GF_HZ_128:
    temp |= 7;
    dof6_hal_write(&adress, &temp, 1);
    break;
  }
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_fifo_water_mark ()
{
  uint8_t adress = FIFO_CONFIG_0;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  return temp;
}

uint8_t dof6_set_fifo_water_mark (uint8_t fifo_water_mark)
{
  uint8_t status = 0;
  uint8_t adress = FIFO_CONFIG_0;
  uint8_t temp = fifo_water_mark;
  if (fifo_water_mark > 255) return status - 1;
  dof6_hal_write(&adress, &temp, 1);

}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_fifo_gyr_en()
{
  return get_bit(FIFO_CONFIG_1, 7);
}

uint8_t dof6_get_fifo_acc_en()
{
  return get_bit(FIFO_CONFIG_1, 6);
}

uint8_t dof6_get_fifo_mag_en()
{
  return get_bit(FIFO_CONFIG_1, 5);
}

uint8_t dof6_get_fifo_header_en()
{
  return get_bit(FIFO_CONFIG_1, 4);
}

uint8_t dof6_get_fifo_tag_int1_en()
{
  return get_bit(FIFO_CONFIG_1, 3);
}

uint8_t dof6_get_fifo_tag_int2_en()
{
  return get_bit(FIFO_CONFIG_1, 2);
}

uint8_t dof6_get_fifo_time_en()
{
  return get_bit(FIFO_CONFIG_1, 1);
}


void dof6_set_fifo_gyr_en(bool set)
{
  if (set)  set_bit(FIFO_CONFIG_1, 7);
  else     clear_bit (FIFO_CONFIG_1, 7);
}

void dof6_set_fifo_acc_en(bool set)
{
  if (set)  set_bit(FIFO_CONFIG_1, 6);
  else     clear_bit (FIFO_CONFIG_1, 6);
}

void dof6_set_fifo_mag_en(bool set)
{
  if (set)  set_bit(FIFO_CONFIG_1, 5);
  else     clear_bit (FIFO_CONFIG_1, 5);
}

void dof6_set_fifo_header_en(bool set)
{
  if (set)  set_bit(FIFO_CONFIG_1, 4);
  else     clear_bit (FIFO_CONFIG_1, 4);
}

void dof6_set_fifo_tag_int1_en(bool set)
{
  if (set)  set_bit(FIFO_CONFIG_1, 3);
  else     clear_bit (FIFO_CONFIG_1, 3);
}

void dof6_set_fifo_tag_int2_en(bool set)
{
  if (set)  set_bit(FIFO_CONFIG_1, 2);
  else     clear_bit (FIFO_CONFIG_1, 2);
}
void dof6_set_fifo_time_en(bool set)
{
  if (set)  set_bit(FIFO_CONFIG_1, 1);
  else     clear_bit (FIFO_CONFIG_1, 1);
}

///////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_mag_i2c_adress()
{
  uint8_t adress = MAG_IF_0;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 1;
  temp &= 0x7F;
  return temp;
}

uint8_t dof6_set_mag_i2c_adress(uint8_t adr)
{
  uint8_t status = 0;
  uint8_t temp;
  uint8_t adress = MAG_IF_0;
  if ( adr > 0x7F ) return status = -1;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0xFE);
  temp |= (adr << 1);
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_mag_manual_en()
{
  return get_bit(MAG_IF_1, 7);
}

void dof6_set_mag_manual_en(bool set)
{
  if (set)  set_bit(MAG_IF_1, 1);
  else   clear_bit (MAG_IF_1, 1);
}

uint8_t dof6_get_mag_offset()
{
  uint8_t adress = MAG_IF_1;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 2;
  temp &= 0x0F;
  return temp;
}

void dof6_set_mag_offset(uint8_t offset)
{
  uint8_t temp;
  uint8_t adress = MAG_IF_1;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x3C);
  temp |= (offset << 2);
  dof6_hal_write(&adress, &temp, 1);

}

uint8_t  dof6_get_mag_rd_burst()
{
  uint8_t adress = MAG_IF_1;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x03;
  if (temp == 0) return 1;
  if (temp == 1) return 2;
  if (temp == 2) return 6;
  if (temp == 3) return 8;
}

void dof6_set_mag_rd_burst(mag_rd_burst rd)
{
  uint8_t adress = MAG_IF_1;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x03);
  switch (rd)
  {
  case RD_1_BYTE:
    dof6_hal_write(&adress, &temp, 1);
    break;
  case RD_2_BYTE:
    temp |= 1;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case RD_6_BYTE:
    temp |= 2;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case RD_8_BYTE:
    temp |= 3;
    dof6_hal_write(&adress, &temp, 1);
    break;
  }
}

////////////////////////////////////////////////////////////////////////////////

uint8_t  dof6_get_mag_read_adress()
{
  uint8_t adress = MAG_IF_2;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  return temp;
}

uint8_t dof6_set_mag_read_adress(uint8_t adr)
{
  uint8_t status = 0;
  uint8_t adress = MAG_IF_2;
  if (adr > 255) return status = -1;
  dof6_hal_write(&adress, &adr, 1);
  return status = 0;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t  dof6_get_mag_write_adress()
{
  uint8_t adress = MAG_IF_3;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  return temp;
}

uint8_t dof6_set_mag_write_adress(uint8_t adr)
{
  uint8_t status = 0;
  uint8_t adress = MAG_IF_3;
  if (adr > 255) return status = -1;
  dof6_hal_write(&adress, &adr, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t  dof6_get_mag_write_data()
{
  uint8_t adress = MAG_IF_4;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  return temp;
}

uint8_t dof6_set_mag_write_data(uint8_t adr)
{
  uint8_t status = 0;
  uint8_t adress = MAG_IF_4;
  if (adr > 255) return status = -1;
  dof6_hal_write(&adress, &adr, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int_flat_en()
{
  return get_bit( INT_EN_0, 7);
}


void dof6_set_int_flat_en(bool set)
{
  if (set)  set_bit(INT_EN_0, 7);
  else    clear_bit (INT_EN_0, 7);
}

uint8_t dof6_get_int_orient_en()
{
  return get_bit( INT_EN_0, 6);
}


void dof6_set_int_orient_en(bool set)
{
  if (set)  set_bit(INT_EN_0, 6);
  else    clear_bit (INT_EN_0, 6);
}

uint8_t dof6_get_int_s_tap_en()
{
  return get_bit( INT_EN_0, 5);
}


void dof6_set_int_s_tap_en(bool set)
{
  if (set)  set_bit(INT_EN_0, 5);
  else     clear_bit (INT_EN_0, 5);
}

uint8_t dof6_get_int_d_tap_en()
{
  return get_bit( INT_EN_0, 4);
}


void dof6_set_int_d_tap_en(bool set)
{
  if (set)  set_bit(INT_EN_0, 4);
  else     clear_bit (INT_EN_0, 4);
}

uint8_t dof6_get_int_anymo_z_en()
{
  return get_bit( INT_EN_0, 2);
}


void dof6_set_int_anymo_z_en(bool set)
{
  if (set)  set_bit(INT_EN_0, 2);
  else     clear_bit (INT_EN_0, 2);
}

uint8_t dof6_get_int_anymo_y_en()
{
  return get_bit( INT_EN_0, 1);
}


void dof6_set_int_anymo_y_en(bool set)
{
  if (set)  set_bit(INT_EN_0, 1);
  else     clear_bit (INT_EN_0, 1);
}


uint8_t dof6_get_int_anymo_x_en()
{
  return get_bit( INT_EN_0, 0);
}


void dof6_set_int_anymo_x_en(bool set)
{
  if (set)  set_bit(INT_EN_0, 0);
  else     clear_bit (INT_EN_0, 0);
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int_fwm_en()
{
  return get_bit( INT_EN_1, 6);
}


void dof6_set_int_fwm_en(bool set)
{
  if (set)  set_bit(INT_EN_1, 6);
  else     clear_bit (INT_EN_1, 6);
}

uint8_t dof6_get_int_ffull_en()
{
  return get_bit( INT_EN_1, 5);
}


void dof6_set_int_ffull_en(bool set)
{
  if (set)  set_bit(INT_EN_1, 5);
  else     clear_bit (INT_EN_1, 5);
}

uint8_t dof6_get_int_drdy_en()
{
  return get_bit( INT_EN_1, 4);
}


void dof6_set_int_drdy_en(bool set)
{
  if (set)  set_bit(INT_EN_1, 4);
  else     clear_bit (INT_EN_1, 4);
}

uint8_t dof6_get_int_low_en()
{
  return get_bit( INT_EN_1, 3);
}


void dof6_set_int_low_en(bool set)
{
  if (set)  set_bit(INT_EN_1, 3);
  else    clear_bit (INT_EN_1, 3);
}

uint8_t dof6_get_int_highz_en()
{
  return get_bit( INT_EN_1, 2);
}


void dof6_set_int_highz_en(bool set)
{
  if (set)  set_bit(INT_EN_1, 2);
  else     clear_bit (INT_EN_1, 2);
}

uint8_t dof6_get_int_highy_en()
{
  return get_bit( INT_EN_1, 1);
}


void dof6_set_int_highy_en(bool set)
{
  if (set)  set_bit(INT_EN_1, 1);
  else     clear_bit (INT_EN_1, 1);
}


uint8_t dof6_get_int_highx_en()
{
  return get_bit( INT_EN_1, 0);
}


void dof6_set_int_highx_en(bool set)
{
  if (set)  set_bit(INT_EN_1, 0);
  else     clear_bit (INT_EN_1, 0);
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int_step_det_en()
{
  return get_bit( INT_EN_2, 3);
}


void dof6_set_int_step_det_en(bool set)
{
  if (set)  set_bit(INT_EN_2, 3);
  else     clear_bit (INT_EN_2, 3);
}

uint8_t dof6_get_int_nomoz_en()
{
  return get_bit( INT_EN_2, 2);
}


void dof6_set_int_nomoz_en(bool set)
{
  if (set)  set_bit(INT_EN_2, 2);
  else     clear_bit (INT_EN_2, 2);
}

uint8_t dof6_get_int_nomoy_en()
{
  return get_bit( INT_EN_2, 1);
}


void dof6_set_int_nomoy_en(bool set)
{
  if (set)  set_bit(INT_EN_2, 1);
  else     clear_bit (INT_EN_2, 1);
}

uint8_t dof6_get_int_nomox_en()
{
  return get_bit( INT_EN_2, 0);
}


void dof6_set_int_nomox_en(bool set)
{
  if (set)  set_bit(INT_EN_2, 0);
  else     clear_bit (INT_EN_2, 0);
}

/////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int2_output_en()
{
  return get_bit(INT_OUT_CTRL, 7);
}


void dof6_set_int2_output_en(bool set)
{
  if (set)  set_bit( INT_OUT_CTRL, 7);
  else     clear_bit ( INT_OUT_CTRL, 7);
}

uint8_t dof6_get_int2_od()
{
  return get_bit(  INT_OUT_CTRL, 6);
}


void dof6_set_int2_od(bool set)
{
  if (set)  set_bit( INT_OUT_CTRL, 6);
  else     clear_bit ( INT_OUT_CTRL, 6);
}

uint8_t dof6_get_int2_lvl()
{
  return get_bit(  INT_OUT_CTRL, 5);
}


void dof6_set_int2_lvl(bool set)
{
  if (set)  set_bit( INT_OUT_CTRL, 5);
  else     clear_bit ( INT_OUT_CTRL, 5);
}

uint8_t dof6_get_int2_edge_crtl()
{
  return get_bit(  INT_OUT_CTRL, 4);
}


void dof6_set_int2_edge_crtl(bool set)
{
  if (set)  set_bit( INT_OUT_CTRL, 4);
  else     clear_bit ( INT_OUT_CTRL, 4);
}

uint8_t dof6_get_int1_output_en()
{
  return get_bit(INT_OUT_CTRL, 3);
}


void dof6_set_int1_output_en(bool set)
{
  if (set)  set_bit( INT_OUT_CTRL, 3);
  else     clear_bit ( INT_OUT_CTRL, 3);
}

uint8_t dof6_get_int1_od()
{
  return get_bit(  INT_OUT_CTRL, 2);
}


void dof6_set_int1_od(bool set)
{
  if (set)  set_bit( INT_OUT_CTRL, 2);
  else     clear_bit ( INT_OUT_CTRL, 2);
}

uint8_t dof6_get_int1_lvl()
{
  return get_bit(  INT_OUT_CTRL, 1);
}


void dof6_set_int1_lvl(bool set)
{
  if (set)  set_bit( INT_OUT_CTRL, 1);
  else     clear_bit ( INT_OUT_CTRL, 1);
}

uint8_t dof6_get_int1_edge_crtl()
{
  return get_bit(  INT_OUT_CTRL, 0);
}


void dof6_set_int1_edge_crtl(bool set)
{
  if (set)  set_bit( INT_OUT_CTRL, 0);
  else     clear_bit ( INT_OUT_CTRL, 0);
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int2_input_en()
{
  return get_bit(  INT_LATCH, 5);
}


void dof6_set_int2_input_en(bool set)
{
  if (set)  set_bit( INT_LATCH, 5);
  else     clear_bit ( INT_LATCH, 5);
}

uint8_t dof6_get_int1_input_en()
{
  return get_bit(  INT_LATCH, 4);
}


void dof6_set_int1_input_en(bool set)
{
  if (set)  set_bit( INT_LATCH, 4);
  else     clear_bit ( INT_LATCH, 4);
}


float dof6_get_int_latch()
{
  uint8_t adress = INT_LATCH;
  uint8_t temp;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x0F;
  if (temp == 0) return 0;
  if (temp == 0x0F) return 1;
  t = 0.3125 * pow(2, temp - 1);
  return t;
}

void dof6_set_int_latch(int_latch_interrupt_modes int_latch)
{
  uint8_t adress = INT_LATCH;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(15) ;
  switch (int_latch)
  {

  case NON_LATCHED:
    temp |= 0;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case TEM_312_5_mis:
    temp |= 1;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case TEM_625_mis:
    temp |= 2;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case  TEM_1_25_ms:
    temp |= 3;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case TEM_2_5_ms:
    temp |= 4;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case TEM_5_ms:
    temp |= 5;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case TEM_10_ms:
    temp |= 6;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case TEM_20_ms:
    temp |= 7;
    dof6_hal_write(&adress, &temp, 1);
    break;

  case TEM_40_ms:
    temp |= 8;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case TEM_80_ms:
    temp |= 9;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case TEM_160_ms:
    temp |= 10;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case  TEM_320_ms:
    temp |= 11;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case TEM_640_ms:
    temp |= 12;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case  TEM_1_28_s:
    temp |= 13;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case TEM_2_56_s:
    temp |= 14;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case LATCHED:
    temp |= 15;
    dof6_hal_write(&adress, &temp, 1);
    break;
  }
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int1_flat()
{
  return get_bit(  INT_MAP_0, 7);
}


void    dof6_set_int1_flat(bool set)
{
  if (set)  set_bit( INT_MAP_0, 7);
  else     clear_bit ( INT_MAP_0, 7);

}

uint8_t dof6_get_int1_orient()
{
  return get_bit(  INT_MAP_0, 6);
}


void   dof6_set_int1_orient(bool set)
{
  if (set)  set_bit( INT_MAP_0, 6);
  else     clear_bit ( INT_MAP_0, 6);

}
uint8_t dof6_get_int1_s_tap()
{
  return get_bit(  INT_MAP_0, 5);
}


void   dof6_set_int1_s_tap(bool set)
{
  if (set)  set_bit( INT_MAP_0, 5);
  else     clear_bit ( INT_MAP_0, 5);

}
uint8_t dof6_get_int1_d_tap()
{
  return get_bit(  INT_MAP_0, 4);
}


void    dof6_set_int1_d_tap(bool set)
{
  if (set)  set_bit( INT_MAP_0, 4);
  else     clear_bit ( INT_MAP_0, 4);

}
uint8_t dof6_get_int1_nomotion()
{
  return get_bit(  INT_MAP_0, 3);
}


void    dof6_set_int1_nomotion(bool set)
{
  if (set)  set_bit( INT_MAP_0, 3);
  else     clear_bit ( INT_MAP_0, 3);

}
uint8_t dof6_get_int1_anymotion()
{
  return get_bit(  INT_MAP_0, 2);
}


void    dof6_set_int1_anymotion(bool set)
{
  if (set)  set_bit( INT_MAP_0, 2);
  else     clear_bit ( INT_MAP_0, 2);

}
uint8_t dof6_get_int1_highg()
{
  return get_bit(  INT_MAP_0, 1);
}


void    dof6_set_int1_highg(bool set)
{
  if (set)  set_bit( INT_MAP_0, 1);
  else     clear_bit ( INT_MAP_0, 1);

}

uint8_t dof6_get_int1_lowg_step()
{
  return get_bit(  INT_MAP_0, 0);
}


void    dof6_set_int1_lowg_step(bool set)
{
  if (set)  set_bit( INT_MAP_0, 0);
  else     clear_bit ( INT_MAP_0, 0);

}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int1_drdy()
{
  return get_bit(  INT_MAP_1, 7);
}


void    dof6_set_int1_drdy(bool set)
{
  if (set)  set_bit( INT_MAP_1, 7);
  else     clear_bit ( INT_MAP_1, 7);

}

uint8_t dof6_get_int1_fwm()
{
  return get_bit(  INT_MAP_1, 6);
}


void    dof6_set_int1_fwm(bool set)
{
  if (set)  set_bit( INT_MAP_1, 6);
  else     clear_bit ( INT_MAP_1, 6);

}
uint8_t dof6_get_int1_ffull()
{
  return get_bit(  INT_MAP_1, 5);
}


void    dof6_set_int1_ffull(bool set)
{
  if (set)  set_bit( INT_MAP_1, 5);
  else     clear_bit ( INT_MAP_1, 5);

}
uint8_t dof6_get_int1_pmu_trig()
{
  return get_bit(  INT_MAP_1, 4);
}


void   dof6_set_int1_pmu_trig(bool set)
{
  if (set)  set_bit( INT_MAP_1, 4);
  else     clear_bit ( INT_MAP_1, 4);

}
uint8_t dof6_get_int2_drdy()
{
  return get_bit(  INT_MAP_1, 3);
}


void   dof6_set_int2_drdy(bool set)
{
  if (set)  set_bit( INT_MAP_1, 3);
  else     clear_bit ( INT_MAP_1, 3);

}
uint8_t dof6_get_int2_fwm()
{
  return get_bit(  INT_MAP_1, 2);
}


void    dof6_set_int2_fwm(bool set)
{
  if (set)  set_bit( INT_MAP_1, 2);
  else     clear_bit ( INT_MAP_1, 2);

}
uint8_t dof6_get_int2_ffull()
{
  return get_bit(  INT_MAP_1, 1);
}


void    dof6_set_int2_ffull(bool set)
{
  if (set)  set_bit( INT_MAP_1, 1);
  else     clear_bit ( INT_MAP_1, 1);

}

uint8_t dof6_get_int2_pmu_trig()
{
  return get_bit(  INT_MAP_1, 0);
}


void    dof6_set_int2_pmu_trig(bool set)
{
  if (set)  set_bit( INT_MAP_1, 0);
  else     clear_bit ( INT_MAP_1, 0);

}

//////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int2_flat()
{
  return get_bit(  INT_MAP_2, 7);
}


void    dof6_set_int2_flat(bool set)
{
  if (set)  set_bit( INT_MAP_2, 7);
  else     clear_bit ( INT_MAP_2, 7);

}

uint8_t dof6_get_int2_orient()
{
  return get_bit(  INT_MAP_2, 6);
}


void    dof6_set_int2_orient(bool set)
{
  if (set)  set_bit( INT_MAP_2, 6);
  else     clear_bit ( INT_MAP_2, 6);

}

uint8_t dof6_get_int2_s_tap()
{
  return get_bit(  INT_MAP_2, 5);
}


void   dof6_set_int2_s_tap(bool set)
{
  if (set)  set_bit( INT_MAP_2, 5);
  else     clear_bit ( INT_MAP_2, 5);

}

uint8_t dof6_get_int2_d_tap()
{
  return get_bit(  INT_MAP_2, 4);
}



void    dof6_set_int2_d_tap(bool set)
{
  if (set)  set_bit( INT_MAP_2, 4);
  else     clear_bit ( INT_MAP_2, 4);

}

uint8_t dof6_get_int2_nomotion()
{
  return get_bit(  INT_MAP_2, 3);
}



void    dof6_set_int2_nomotion(bool set)
{
  if (set)  set_bit( INT_MAP_2, 3);
  else     clear_bit ( INT_MAP_2, 3);

}

uint8_t dof6_get_int2_anymotion()
{
  return get_bit(  INT_MAP_2, 2);
}


void    dof6_set_int2_anymotion(bool set)
{
  if (set)  set_bit( INT_MAP_2, 2);
  else     clear_bit ( INT_MAP_2, 2);

}

uint8_t dof6_get_int2_highg()
{
  return get_bit(  INT_MAP_2, 1);
}


void    dof6_set_int2_highg(bool set)
{
  if (set)  set_bit( INT_MAP_2, 1);
  else     clear_bit ( INT_MAP_2, 1);

}

uint8_t dof6_get_int2_lowg_step()
{
  return get_bit(  INT_MAP_2, 0);
}


void    dof6_set_int2_lowg_step(bool set)
{
  if (set)  set_bit( INT_MAP_2, 0);
  else     clear_bit ( INT_MAP_2, 0);

}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int_low_high_src()
{
  return get_bit(  INT_DATA_0, 7);
}


void    dof6_set_int_low_high_src(bool set)
{
  if (set)  set_bit( INT_DATA_0, 7);
  else     clear_bit ( INT_DATA_0, 7);

}

uint8_t dof6_get_int_tap_src()
{
  return get_bit( INT_DATA_0, 3);
}


void    dof6_set_int_tap_src(bool set)
{
  if (set)  set_bit( INT_DATA_0, 3);
  else     clear_bit ( INT_DATA_0, 3);

}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int_motion_src()
{
  return get_bit( INT_DATA_1, 7);
}


void    dof6_set_int_motion_src(bool set)
{
  if (set)  set_bit( INT_DATA_1, 7);
  else     clear_bit ( INT_DATA_1, 7);
}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_int_low_dur()
{
  uint8_t adress = INT_LOWHIGH_0;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  t = (temp + 1) * 2.5;
  return t;
}


uint8_t dof6_set_int_low_dur(float dur)
{
  uint8_t status = 0;
  uint8_t adress = INT_LOWHIGH_0;
  uint8_t temp = 0;
  if (dur < 2.5 || dur > 640) return status = -1;
  temp = (uint8_t)(dur / 2.5);
  temp = temp - 1;
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_int_low_th()
{
  uint8_t adress = INT_LOWHIGH_1;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  if (temp == 0) return 3.91;
  t = temp * 7.81;
  return t;
}


uint8_t dof6_set_int_low_th(float th)
{
  uint8_t status = 0;
  uint8_t adress = INT_LOWHIGH_1;
  uint8_t temp = 0;
  if (th < 3.91 || th > 2000) return status = -1;
  if (th == 3.91) dof6_hal_write(&adress, &temp, 1);
  else {
    temp = (uint8_t)(th / 7.81);
    dof6_hal_write(&adress, &temp, 1);
  }
  return status;
}

////////////////////////////////////////////////////////////////////////////////


float dof6_get_int_highhy(uint8_t a)
{
  uint8_t adress = INT_LOWHIGH_2;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0xC0;
  temp = temp >> 6;
  t = temp * 125 * a;
  return t;

}

float dof6_get_int_high_hy()
{
  if (dof6_get_acc_g_range() == 2 ) return  dof6_get_int_highhy(1);
  if (dof6_get_acc_g_range() == 4 ) return  dof6_get_int_highhy(2);
  if (dof6_get_acc_g_range() == 8 ) return  dof6_get_int_highhy(4);
  if (dof6_get_acc_g_range() == 16 ) return  dof6_get_int_highhy(8);


}


void dof6_set_int_highhy(float hy, uint8_t a)
{
  uint8_t adress = INT_LOWHIGH_2;
  uint8_t temp = 0;
  uint8_t t;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0xC0);
  t = (uint8_t)(hy / (125 * a));
  temp |= (t << 6);
  dof6_hal_write(&adress, &temp, 1);
}

uint8_t dof6_set_int_high_hy(float hy)
{
  uint8_t status = 0;
  if (dof6_get_acc_g_range() == 2 )
  {
    if ( hy < 0 || hy > 375) return status = -1;
    dof6_set_int_highhy(hy, 1);
  }
  if (dof6_get_acc_g_range() == 4 )
  {
    if ( hy < 0 || hy > 750) return status = -1;
    dof6_set_int_highhy(hy, 2);
  }
  if (dof6_get_acc_g_range() == 8 )
  {
    if ( hy < 0 || hy > 1500) return status = -1;
    dof6_set_int_highhy(hy, 4);
  }
  if (dof6_get_acc_g_range() == 16 )
  {
    if ( hy < 0 || hy > 3000) return status = -1;
    dof6_set_int_highhy(hy, 8);
  }
  return status;
}

uint8_t dof6_get_int_low_mode()
{
  return get_bit( INT_LOWHIGH_2, 2);
}


void    dof6_set_int_low_mode(bool set)
{
  if (set)  set_bit( INT_LOWHIGH_2, 2);
  else     clear_bit ( INT_LOWHIGH_2, 2);

}


float dof6_get_int_low_hy()
{
  uint8_t adress = INT_LOWHIGH_2;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x03;
  t = temp * 125;
  return t;
}

uint8_t dof6_set_int_low_hy(float hy)
{
  uint8_t adress = INT_LOWHIGH_2;
  uint8_t status = 0;
  uint8_t temp = 0;
  uint8_t t;
  if ( hy < 0 || hy > 375) return status = -1;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x03);
  t = (uint8_t)(hy / 125);
  temp |= t;
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_int_high_dur()
{
  uint8_t adress = INT_LOWHIGH_3;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  t = (temp + 1) * 2.5;
  return t;
}

uint8_t dof6_set_int_high_dur(float dur)
{
  uint8_t status = 0;
  uint8_t adress = INT_LOWHIGH_3;
  uint8_t temp = 0;
  uint8_t t;
  if (dur < 2.5 || dur > 650) return status = -1;
  t = (uint8_t)(dur / 2.5);
  temp = t - 1;
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

float  dof6_get_int_high_t(float a, float b)
{
  uint8_t adress = INT_LOWHIGH_4;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  if (temp == 0) return b;
  t = temp * a;
  return t;
}

float dof6_get_int_high_th()
{
  if (dof6_get_acc_g_range() == 2 )  return dof6_get_int_high_t(7.81, 3.91);
  if (dof6_get_acc_g_range() == 4 ) return  dof6_get_int_high_t(15.63, 7.81);
  if (dof6_get_acc_g_range() == 8 ) return  dof6_get_int_high_t(31.25, 15.63);
  if (dof6_get_acc_g_range() == 16 ) return  dof6_get_int_high_t(62.5, 31.25);
}

void dof6_set_int_high_t(float dur, float a, float b)
{
  uint8_t adress = INT_LOWHIGH_4;
  uint8_t temp = 0;
  if (dur == b)  dof6_hal_write(&adress, &temp, 1);
  else
  {
    temp = (uint8_t)(dur / a);
    dof6_hal_write(&adress, &temp, 1);
  }
}

uint8_t dof6_set_int_high_th(float dur)
{
  uint8_t status = 0;
  if (dof6_get_acc_g_range() == 2 )
  {
    if (dur < 3.91 || dur > 1991.55) return status = -1;
    dof6_set_int_high_t(dur, 7.81, 3.91);
  }
  if (dof6_get_acc_g_range() == 4 )
  {
    if (dur < 7.81 || dur > 3985.65) return status = -1;
    dof6_set_int_high_t(dur, 15.63, 7.81);
  }
  if (dof6_get_acc_g_range() == 8 )
  {
    if (dur < 15.63 || dur > 7968.75) return status = -1;
    dof6_set_int_high_t(dur, 31.25, 15.63);
  }
  if (dof6_get_acc_g_range() == 16 )
  {
    if (dur < 31.25 || dur > 15937.5) return status = -1;
    dof6_set_int_high_t(dur, 62.5, 31.25);
  }
  return status;
}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_int_slo_nomo_dur()
{
  uint8_t adress = INT_MOTION_0;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  if (dof6_get_int_slo_nomo_sel() == 1)
  {
    temp = temp >> 6;
    if (temp == 0)
    {
      dof6_hal_read(&adress, &temp, 1);
      temp = temp >> 2;
      temp &= 0x0F;
      t = (temp + 1) * 1.28;
      return t;
    }
    else if (temp == 1)
    {
      dof6_hal_read(&adress, &temp, 1);
      temp = temp >> 2;
      temp &= 0x0F;
      t = (temp + 1) * 5.12;
      return t;
    }
    else if (temp == 2 || temp == 3)
    {
      dof6_hal_read(&adress, &temp, 1);
      temp = temp >> 2;
      temp &= 0x1F;
      t = (temp + 11) * 10.24;
      return t;
    }
  }
  else
  {
    temp = temp >> 2;
    temp &= 0x03;
    temp += 1;
    return temp;
  }
}

int8_t dof6_set_int_slo_nomo_dur(float dur)
{
  uint8_t adress = INT_MOTION_0;
  uint8_t temp = 0;
  uint8_t status = 0;
  uint8_t t = 0;
  dof6_hal_read(&adress, &temp, 1);
  if (dof6_get_int_slo_nomo_sel() == 1)
  {
    if (dur > 1.28 && dur < 20.48 )
    {
      t = (uint8_t)(dur / 1.28 - 1);
      temp &= ~(0x3C);
      temp |= (t << 2);
      dof6_hal_write(&adress, &temp, 1);
      return status;
    }
    if (dur > 25.6 && dur < 102.4)
    {
      t = (uint8_t)(dur / 5.12 - 5);
      temp &= ~(0x3C);
      temp |= (t << 2);
      dof6_hal_write(&adress, &temp, 1);
      return status;
    }
    if (dur > 112.64 && dur < 430.08 )
    {
      t = (uint8_t)(dur / 10.24 - 11);
      temp &= ~(0x7C);
      temp |= (t << 2);
      dof6_hal_write(&adress, &temp, 1);
      return status;
    }
    return status = -1 ;
  }
  else
  {
    if (dur > 4 && dur < 1) return status = -1;
    temp &= ~(0x0C);
    dur -= 1;
    t = (uint8_t) dur;
    t = t << 2;
    temp |= t;
    dof6_hal_write(&adress, &temp, 1);
    return status;
  }
}

uint8_t  dof6_get_int_anym_dur()
{
  uint8_t adress = INT_MOTION_0;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x03;
  temp = temp + 1;
  return temp;
}


int8_t dof6_set_int_anym_dur(uint8_t dur)
{
  uint8_t status = 0;
  uint8_t adress = INT_MOTION_0;
  uint8_t temp = 0;
  if (dur < 1 || dur > 4) return status = -1;
  dur -= 1;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x03);
  temp |= dur;
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

float  dof6_get_int_anymo_t(float a, float b)
{
  uint8_t adress = INT_MOTION_1;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  if (temp == 0) return b;
  t = temp * a;
  return t;
}

float dof6_get_int_anymo_th()
{
  if (dof6_get_acc_g_range() == 2 )  return dof6_get_int_anymo_t(3.91, 1.95);
  if (dof6_get_acc_g_range() == 4 ) return  dof6_get_int_anymo_t(7.81, 3.91);
  if (dof6_get_acc_g_range() == 8 ) return  dof6_get_int_anymo_t(15.63, 7.81);
  if (dof6_get_acc_g_range() == 16 ) return  dof6_get_int_anymo_t(31.25, 15.63);
}

void dof6_set_int_anymo_t(float th, float a, float b)
{
  uint8_t adress = INT_MOTION_1;
  uint8_t temp = 0;
  if (th == b) dof6_hal_write(&adress, &temp, 1);
  else {
    temp = (uint8_t)(th / a);
    dof6_hal_write(&adress, &temp, 1);
  }
}

uint8_t dof6_set_int_anymo_th(float th)
{
  uint8_t status = 0;
  if (dof6_get_acc_g_range() == 2 )
  {
    if (th < 1.95 || th > 997.05) return status = -1;
    dof6_set_int_anymo_t(th, 3.91, 1.95);
  }
  if (dof6_get_acc_g_range() == 4 )
  {
    if (th < 3.91 || th > 1991.55) return status = -1;
    dof6_set_int_anymo_t(th, 7.81, 3.91);
  }
  if (dof6_get_acc_g_range() == 8 )
  {
    if (th < 7.81 || th > 3985.65) return status = -1;
    dof6_set_int_anymo_t(th, 15.63, 7.81);
  }
  if (dof6_get_acc_g_range() == 16 )
  {
    if (th < 15.63 || th > 7968.75) return status = -1;
    dof6_set_int_anymo_t(th, 31.25, 15.63);
  }
  return status;
}



////////////////////////////////////////////////////////////////////////////////

float  dof6_get_int_slo_nomo_t(float a, float b)
{
  uint8_t adress = INT_MOTION_2;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  if (temp == 0) return b;
  t = temp * a;
  return t;
}

float dof6_get_int_slo_nomo_th()
{
  if (dof6_get_acc_g_range() == 2 )  return dof6_get_int_slo_nomo_t(3.91, 1.95);
  if (dof6_get_acc_g_range() == 4 ) return  dof6_get_int_slo_nomo_t(7.81, 3.91);
  if (dof6_get_acc_g_range() == 8 ) return  dof6_get_int_slo_nomo_t(15.63, 7.81);
  if (dof6_get_acc_g_range() == 16 ) return  dof6_get_int_slo_nomo_t(31.25, 15.63);
}

void dof6_set_int_slo_nomo_t(float th, float a, float b)
{
  uint8_t adress = INT_MOTION_2;
  uint8_t temp = 0;
  if (th == b) dof6_hal_write(&adress, &temp, 1);
  else
  {
    temp = (uint8_t)(th / a);
    dof6_hal_write(&adress, &temp, 1);
  }
}

uint8_t dof6_set_int_slo_nomo_th(float th)
{
  uint8_t status = 0;
  if (dof6_get_acc_g_range() == 2 )
  {
    if (th < 1.95 || th > 997.05) return status = -1;
    dof6_set_int_slo_nomo_t(th, 3.91, 1.95);
  }
  if (dof6_get_acc_g_range() == 4 )
  {
    if (th < 3.91 || th > 1991.55) return status = -1;
    dof6_set_int_slo_nomo_t(th, 7.81, 3.91);
  }
  if (dof6_get_acc_g_range() == 8 )
  {
    if (th < 7.81 || th > 3985.65) return status = -1;
    dof6_set_int_slo_nomo_t(th, 15.63, 7.81);
  }
  if (dof6_get_acc_g_range() == 16 )
  {
    if (th < 15.63 || th > 7968.75) return status = -1;
    dof6_set_int_slo_nomo_t(th, 31.25, 15.63);
  }
  return status;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int_slo_nomo_sel()
{
  return get_bit(  INT_MOTION_3 , 0);
}


void    dof6_set_int_slo_nomo_sel(bool set)
{
  if (set)  set_bit( INT_MOTION_3 , 0);
  else     clear_bit ( INT_MOTION_3 , 0);

}

uint8_t dof6_get_int_sig_mot_sel()
{
  return get_bit( INT_MOTION_3 , 1);
}


void    dof6_set_int_sig_mot_sel(bool set)
{
  if (set)  set_bit( INT_MOTION_3 , 1);
  else     clear_bit ( INT_MOTION_3 , 1);

}

float dof6_get_int_sig_mot_skip()
{
  uint8_t adress = INT_MOTION_3;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 2;
  temp &= 3;
  if (temp == 0) return 1.5;
  if (temp == 1) return 3;
  if (temp == 2) return 6;
  if (temp == 3) return 12;
}


int8_t   dof6_set_int_sig_mot_skip(int_sig_mot_skip time)
{
  uint8_t adress = INT_MOTION_3;
  uint8_t temp = 0;
  uint8_t  status = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x0C);
  switch (time)
  {
  case SKIP_TIME_1_5_s :
    dof6_hal_write(&adress, &temp, 1);
    break;
  case SKIP_TIME_3_s :
    temp |= 0x04;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case SKIP_TIME_6_s :
    temp |= 0x08;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case SKIP_TIME_12_s :
    temp |= 0x0C;
    dof6_hal_write(&adress, &temp, 1);
    break;
  default:
    status = -1;
    break;
  }
  return status;

}

float dof6_get_int_sig_mot_proof()
{
  uint8_t adress = INT_MOTION_3;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 4;
  temp &= 3;
  if (temp == 0) return 0.25;
  if (temp == 1) return 0.5;
  if (temp == 2) return 1;
  if (temp == 3) return 2;
}


int8_t   dof6_set_int_sig_mot_proof(int_sig_mot_skip time)
{
  uint8_t adress = INT_MOTION_3;
  uint8_t temp = 0;
  uint8_t  status = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x30);
  switch (time)
  {
  case PROOF_TIME_0_25_s :
    dof6_hal_write(&adress, &temp, 1);
    break;
  case PROOF_TIME_0_5_s :
    temp |= 0x10;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case PROOF_TIME_1_s :
    temp |= 0x20;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case PROOF_TIME_2_s :
    temp |= 0x30;
    dof6_hal_write(&adress, &temp, 1);
    break;
  default:
    status = -1;
    break;
  }
  return status;

}


////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int_tap_quiet()
{
  return get_bit(  INT_TAP_0 , 7);
}


void    dof6_set_int_tap_quiet(bool set)
{
  if (set)  set_bit( INT_TAP_0 , 7);
  else     clear_bit (INT_TAP_0 , 7);

}

uint8_t dof6_get_int_tap_shock()
{
  return get_bit( INT_TAP_0 , 6);
}


void    dof6_set_int_tap_shock(bool set)
{
  if (set)  set_bit( INT_TAP_0 , 6);
  else     clear_bit ( INT_TAP_0 , 6);

}

uint16_t dof6_get_int_tap_dur()
{
  uint8_t adress = INT_TAP_0;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 7;
  if (temp == 0) return 50;
  if (temp == 1) return 100;
  if (temp == 2) return 150;
  if (temp == 3) return 200;
  if (temp == 4) return 250;
  if (temp == 5) return 375;
  if (temp == 6) return 500;
  if (temp == 7) return 700;
}


int8_t   dof6_set_int_tap_dur(int_tap_dur time)
{
  uint8_t adress = INT_TAP_0;
  uint8_t temp = 0;
  uint8_t  status = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x07);
  switch (time)
  {
  case SECOND_SHOCK_EVENT_50_s :
    dof6_hal_write(&adress, &temp, 1);
    break;
  case SECOND_SHOCK_EVENT_100_s :
    temp |= 1;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case SECOND_SHOCK_EVENT_150_s :
    temp |= 2;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case SECOND_SHOCK_EVENT_200_s :
    temp |= 3;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case SECOND_SHOCK_EVENT_250_s :
    temp |= 4;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case SECOND_SHOCK_EVENT_375_s :
    temp |= 5;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case SECOND_SHOCK_EVENT_500_s :
    temp |= 6;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case SECOND_SHOCK_EVENT_700_s :
    temp |= 7;
    dof6_hal_write(&adress, &temp, 1);
    break;
  default:
    status = -1;
    break;
  }
  return status;

}
////////////////////////////////////////////////////////////////////////////////

float  dof6_get_int_tap_t(float a)
{
  uint8_t adress = INT_TAP_1;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x0F;
  if (temp == 0) return a / 2;
  t = temp * a;
  return t;
}

float dof6_get_int_tap_th()
{
  if (dof6_get_acc_g_range() == 2 )  return dof6_get_int_tap_t(62.5);
  if (dof6_get_acc_g_range() == 4 ) return  dof6_get_int_tap_t(125);
  if (dof6_get_acc_g_range() == 8 ) return  dof6_get_int_tap_t(250);
  if (dof6_get_acc_g_range() == 16 ) return  dof6_get_int_tap_t(500);
}

void dof6_set_int_tap_t(float th, float a)
{
  uint8_t adress = INT_TAP_1;
  uint8_t temp = 0;
  uint8_t t;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x0F);
  if (th == a / 2) dof6_hal_write(&adress, &temp, 1);
  else
  {
    t = (uint8_t)(th / a);
    temp |= t;
    dof6_hal_write(&adress, &temp, 1);
  }
}

uint8_t dof6_set_int_tap_th(float th)
{
  uint8_t status = 0;
  if (dof6_get_acc_g_range() == 2 )
  {
    if (th < 31.25 || th > 1937.5) return status = -1;
    dof6_set_int_tap_t(th, 62.5);
  }
  if (dof6_get_acc_g_range() == 4 )
  {
    if (th < 62.5 || th > 3875) return status = -1;
    dof6_set_int_tap_t(th, 125);
  }
  if (dof6_get_acc_g_range() == 8 )
  {
    if (th < 125 || th > 7750) return status = -1;
    dof6_set_int_tap_t(th, 250);
  }
  if (dof6_get_acc_g_range() == 16 )
  {
    if (th < 250 || th > 15500) return status = -1;
    dof6_set_int_tap_t(th, 500);
  }
  return status;
}



////////////////////////////////////////////////////////////////////////////////

float  dof6_get_int_orient_hy()
{
  uint8_t adress = INT_ORIENT_0;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 4;
  temp &= 0x0F;
  t = temp * 62.5;
  return t;
}


uint8_t dof6_set_int_orient_hy(float th)
{
  uint8_t adress = INT_ORIENT_0;
  uint8_t temp = 0;
  uint8_t t = 0;
  uint8_t status = 0;
  if (th < 0 || th > 1937.5) return status = -1;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0xF0);
  t = (uint8_t)(th / 62.5);
  temp |= (t << 4);
  dof6_hal_write(&adress, &temp, 1);
  return status;
}


uint8_t dof6_get_int_orient_blocking()
{
  uint8_t adress = INT_ORIENT_0;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 2;
  temp &= 3;
  return temp;
}


int8_t   dof6_set_int_orient_blocking(uint8_t block)
{
  uint8_t adress = INT_ORIENT_0;
  uint8_t temp = 0;
  uint8_t  status = 0;
  dof6_hal_read(&adress, &temp, 1);
  if (block < 0 || block > 3) return status = -1;
  temp &= ~(0x0C);
  temp |= (block << 2);
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

uint8_t dof6_get_int_orient_mode()
{
  uint8_t adress = INT_ORIENT_0;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 3;
  return temp;
}


int8_t   dof6_set_int_orient_mode(int_orient_mode mode)
{
  uint8_t adress = INT_ORIENT_0;
  uint8_t temp = 0;
  uint8_t  status = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x03);
  switch (mode)
  {
  case SYMMETRICAL :
    dof6_hal_write(&adress, &temp, 1);
    break;
  case HIGH_SYMMETRICAL :
    temp |= 1;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case LOW_ASYMMETRICAL :
    temp |= 2;
    dof6_hal_write(&adress, &temp, 1);
    break;
  default:
    status = -1;
    break;
  }
  return status;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_int_orient_axes_ex()
{
  return get_bit(  INT_ORIENT_1 , 7);
}


void    dof6_set_int_orient_axes_ex(bool set)
{
  if (set)  set_bit( INT_ORIENT_1 , 7);
  else     clear_bit (INT_ORIENT_1 , 7);

}

uint8_t dof6_get_int_orient_ud_en()
{
  return get_bit( INT_ORIENT_1 , 6);
}


void    dof6_set_int_orient_ud_en(bool set)
{
  if (set)  set_bit( INT_ORIENT_1 , 6);
  else     clear_bit ( INT_ORIENT_1 , 6);

}


float dof6_get_int_orient_theta()
{
  uint8_t adress = INT_ORIENT_1;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x3F;
  t = 0.7 * temp;
  return t;
}

int8_t dof6_set_int_orient_theta(float angle)
{
  uint8_t adress = INT_ORIENT_1;
  uint8_t temp = 0;
  uint8_t t;
  uint8_t status = 0;
  dof6_hal_read(&adress, &temp, 1);
  if (angle < 0 || angle > 44.8) return   status = -1;
  t = (uint8_t) (angle / 0.7);
  temp &= ~(0x3F);
  temp |= t;
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_int_flat_theta()
{
  uint8_t adress = INT_FLAT_0;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x3F;
  t = 0.7 * temp;
  return t;
}

int8_t dof6_set_int_flat_theta(float flat_angle)
{
  uint8_t adress = INT_FLAT_0;
  uint8_t temp = 0;
  uint8_t status = 0;
  uint8_t tem;
  dof6_hal_read(&adress, &temp, 1);
  if (flat_angle < 0 || flat_angle > 44.8) return   status = -1;
  tem = (uint8_t)(flat_angle / 0.7);
  temp &= ~(0x3F);
  temp |= tem;
  dof6_hal_write(&adress, &temp, 1);
  return status;
}
////////////////////////////////////////////////////////////////////////////////

uint16_t dof6_get_int_flat_hold_time()
{
  uint8_t adress = INT_FLAT_1;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 4;
  temp &= 3;
  if (temp == 0) return 0;
  if (temp == 1) return 640;
  if (temp == 2) return 1280;
  if (temp == 3) return 2560;

}


int8_t   dof6_set_int_flat_hold_time(int_flat_hold_time time)
{
  uint8_t adress = INT_FLAT_1;
  uint8_t temp = 0;
  uint8_t  status = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x30);
  switch (time)
  {
  case FLAT_STABLE_0_ms :
    dof6_hal_write(&adress, &temp, 1);
    break;
  case FLAT_STABLE_640_ms :
    temp |= 0x10;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case FLAT_STABLE_1280_ms :
    temp |= 0x20;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case FLAT_STABLE_2560_ms :
    temp |= 0x30;
    dof6_hal_write(&adress, &temp, 1);
    break;
  default:
    status = -1;
    break;
  }
  return status;
}


uint8_t dof6_get_int_flat_hy()
{
  uint8_t adress = INT_FLAT_1;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 0x07;
  return temp;
}

int8_t dof6_set_int_flat_hy(uint8_t flat_hy)
{
  uint8_t adress = INT_FLAT_1;
  uint8_t temp = 0;
  uint8_t status = 0;
  dof6_hal_read(&adress, &temp, 1);
  if (flat_hy < 0 || flat_hy > 7) return   status = -1;
  temp &= ~(0x07);
  temp |= flat_hy;
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_foc_gyr_en()
{
  return get_bit(  FOC_CONF , 6);
}


void    dof6_set_foc_gyr_en(bool set)
{
  if (set)  set_bit( FOC_CONF , 6);
  else     clear_bit (FOC_CONF , 6);

}


int8_t dof6_get_foc_acc_x()
{
  uint8_t adress = FOC_CONF;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 4;
  temp &= 3;
  if (temp == 0) return -2;
  if (temp == 1) return 1;
  if (temp == 2) return -1;
  if (temp == 3) return 0;

}

int8_t   dof6_set_foc_acc_x(foc_acc_x offset)
{
  uint8_t adress = FOC_CONF;
  uint8_t temp = 0;
  uint8_t  status = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x30);
  switch (offset)
  {
  case X_DISABLED :
    dof6_hal_write(&adress, &temp, 1);
    break;
  case X_1_g :
    temp |= 0x10;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case X_minus_1_g :
    temp |= 0x20;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case X_0_g :
    temp |= 0x30;
    dof6_hal_write(&adress, &temp, 1);
    break;
  default:
    status = -1;
    break;
  }

  return status;
}

int8_t dof6_get_foc_acc_y()
{
  uint8_t adress = FOC_CONF;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 2;
  temp &= 3;
  if (temp == 0) return -2;
  if (temp == 1) return 1;
  if (temp == 2) return -1;
  if (temp == 3) return 0;

}

int8_t   dof6_set_foc_acc_y(foc_acc_y offset)
{
  uint8_t adress = FOC_CONF;
  uint8_t temp = 0;
  uint8_t  status = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x0C);
  switch (offset)
  {
  case Y_DISABLED :
    dof6_hal_write(&adress, &temp, 1);
    break;
  case Y_1_g :
    temp |= 0x04;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case Y_minus_1_g :
    temp |= 0x08;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case Y_0_g :
    temp |= 0x0C;
    dof6_hal_write(&adress, &temp, 1);
    break;
  default:
    status = -1;
    break;
  }
  return status;
}

int8_t dof6_get_foc_acc_z()
{
  uint8_t adress = FOC_CONF;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 3;
  if (temp == 0) return -2;
  if (temp == 1) return 1;
  if (temp == 2) return -1;
  if (temp == 3) return 0;

}

int8_t   dof6_set_foc_acc_z(foc_acc_y offset)
{
  uint8_t adress = FOC_CONF;
  uint8_t temp = 0;
  uint8_t  status = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x03);
  switch (offset)
  {
  case Z_DISABLED :
    dof6_hal_write(&adress, &temp, 1);
    break;
  case Z_1_g :
    temp |= 0x01;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case Z_minus_1_g :
    temp |= 0x02;
    dof6_hal_write(&adress, &temp, 1);
    break;
  case Z_0_g :
    temp |= 0x03;
    dof6_hal_write(&adress, &temp, 1);
    break;
  default:
    status = -1;
    break;
  }
  return status;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_nvm_prog_en()
{
  return get_bit(CONF , 1);
}


void    dof6_set_nvm_prog_en(bool set)
{
  if (set)  set_bit( CONF , 1);
  else     clear_bit (CONF , 1);

}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_spi3()
{
  return get_bit(IF_CONF , 1);
}


void    dof6_set_spi3(bool set)
{
  if (set)  set_bit(IF_CONF , 1);
  else     clear_bit (IF_CONF , 1);

}

uint8_t dof6_get_if_mode()
{
  uint8_t adress = IF_CONF;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 4;
  temp &= 3;
  return temp;

}

int8_t dof6_set_if_mode(uint8_t if_mode)
{
  uint8_t adress = IF_CONF;
  uint8_t temp = 0;
  uint8_t status = 0;
  if (if_mode < 0 || if_mode > 3) return status = -1;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x30);
  temp |= (if_mode << 4);
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_wakeup_int()
{
  return get_bit(PMU_TRIGGER , 6);
}


void    dof6_set_wakeup_int(bool set)
{
  if (set)  set_bit(PMU_TRIGGER , 6);
  else     clear_bit (PMU_TRIGGER , 6);

}

uint8_t dof6_get_gyr_sleep_state()
{
  return get_bit(PMU_TRIGGER , 5);
}


void    dof6_set_gyr_sleep_state(bool set)
{
  if (set)  set_bit(PMU_TRIGGER , 5);
  else     clear_bit (PMU_TRIGGER , 5);

}

uint8_t dof6_get_gyr_wakeup_trigg()
{
  uint8_t adress = PMU_TRIGGER;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 3;
  temp &= 3;
  return temp;
}

int8_t dof6_set_gyr_wakeup_trigg(uint8_t gyr_wakeup)
{
  uint8_t adress = PMU_TRIGGER;
  uint8_t temp = 0;
  uint8_t status = 0;
  if (gyr_wakeup < 0 || gyr_wakeup > 3) return status = -1;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x18);
  temp |= (gyr_wakeup << 3);
  dof6_hal_write(&adress, &temp, 1);
  return status;
}


uint8_t dof6_get_gyr_sleep_trigger()
{
  uint8_t adress = PMU_TRIGGER;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 7;
  return temp;
}

int8_t dof6_set_gyr_sleep_trigger(uint8_t gyr_sleep)
{
  uint8_t adress = PMU_TRIGGER;
  uint8_t temp = 0;
  uint8_t status = 0;
  if (gyr_sleep < 0 || gyr_sleep > 7) return status = -1;
  dof6_hal_read(&adress, &temp, 1);
  temp &= ~(0x07);
  temp |= gyr_sleep;
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_gyr_self_test_enable()
{
  return get_bit(SELF_TEST , 4);
}


void   dof6_set_gyr_self_test_enable(bool set)
{
  if (set)  set_bit(SELF_TEST , 4);
  else     clear_bit (SELF_TEST , 4);

}

uint8_t dof6_get_acc_self_test_amp()
{
  return get_bit(SELF_TEST , 3);
}


void   dof6_set_acc_self_test_amp(bool set)
{
  if (set)  set_bit(SELF_TEST , 3);
  else     clear_bit (SELF_TEST , 3);

}

uint8_t dof6_get_acc_self_test_sign()
{
  return get_bit(SELF_TEST , 2);
}


void   dof6_set_acc_self_test_sign(bool set)
{
  if (set)  set_bit(SELF_TEST , 2);
  else     clear_bit (SELF_TEST , 2);

}

uint8_t dof6_get_acc_self_test_enable()
{
  uint8_t adress = SELF_TEST;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 3;
  return temp;
}

void  dof6_set_acc_self_test_enable(bool set)
{
  uint8_t adress = SELF_TEST;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  if (set)
  {
    temp |= 1;
    dof6_hal_write(&adress, &temp, 1);
  }
  else dof6_hal_write(&adress, &temp, 1);
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_i2c_wdt_en()
{
  return get_bit(NV_CONF , 2);
}


void   dof6_set_i2c_wdt_en(bool set)
{
  if (set)  set_bit(NV_CONF , 2);
  else     clear_bit (NV_CONF , 2);

}

uint8_t dof6_get_i2c_wdt_sel()
{
  return get_bit(NV_CONF , 1);
}


void   dof6_set_i2c_wdt_sel(bool set)
{
  if (set)  set_bit(NV_CONF , 1);
  else     clear_bit (NV_CONF , 1);

}

uint8_t dof6_get_spi_en()
{
  return get_bit(NV_CONF , 0);
}


void    dof6_set_spi_en(bool set)
{
  if (set)  set_bit(NV_CONF , 0);
  else     clear_bit (NV_CONF , 0);

}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_off_acc_x()
{
  uint8_t adress = OFFSET_0;
  int8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  t = temp * 3.9;
  return t;

}

uint8_t  dof6_set_off_acc_x(float offset)
{
  uint8_t adress = OFFSET_0;
  int8_t temp;
  uint8_t status = 0;
  if (offset < -495.3 || offset > 495.3) return status = -1;
  temp = (int8_t) (offset / 3.9);
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_off_acc_y()
{
  uint8_t adress = OFFSET_1;
  int8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  t = temp * 3.9;
  return t;
}

uint8_t  dof6_set_off_acc_y(float offset)
{
  uint8_t adress = OFFSET_1;
  int8_t temp;
  uint8_t status = 0;
  if (offset < -495.3 || offset > 495.3) return status = -1;
  temp = (int8_t) (offset / 3.9);
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_off_acc_z()
{
  uint8_t adress = OFFSET_2;
  uint8_t temp = 0;
  float t;
  dof6_hal_read(&adress, &temp, 1);
  t = temp * 3.9;
  return t;
}

uint8_t  dof6_set_off_acc_z(float offset)
{
  uint8_t adress = OFFSET_2;
  uint8_t temp;
  uint8_t status = 0;
  if (offset < -495.3 || offset > 495.3) return status = -1;
  temp = (uint8_t) (offset / 3.9);
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_off_gyr_x()
{
  uint8_t adress1 = OFFSET_3;
  uint8_t adress2 = OFFSET_6;
  int8_t temp1 = 0;
  int8_t temp2 = 0;
  int16_t temp = 0;
  float t;
  dof6_hal_read(&adress1, &temp1, 1);
  dof6_hal_read(&adress2, &temp2, 1);
  temp2 &= 3;
  temp += temp1;
  temp |= (temp2 << 8);
  if (temp2 == 3 || temp2 == 2)
  {
    temp = ~(temp) + 1;
    temp &= 1023;
    temp = -temp;
  }
  t = temp * 0.061;
  return t;
}

uint8_t  dof6_set_off_gyr_x(float offset)
{
  uint8_t adress1 = OFFSET_3;
  uint8_t adress2 = OFFSET_6;
  int16_t temp;
  int8_t temp1;
  int8_t temp2;
  int8_t t;
  uint8_t status = 0;
  if (offset < -31.25 || offset > 31.25) return status = -1;
  temp = (int16_t) (offset / 0.061);
  temp1 = (int8_t) temp;
  temp2 = (int8_t) (temp >> 8);
  dof6_hal_write(&adress1, &temp1, 1);
  dof6_hal_read(&adress2, &t, 1);
  t &= ~(0x03);
  t |= temp2;
  dof6_hal_write(&adress2, &t, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_off_gyr_y()
{
  uint8_t adress1 = OFFSET_3;
  uint8_t adress2 = OFFSET_6;
  int8_t temp1 = 0;
  int8_t temp2 = 0;
  int16_t temp = 0;
  float t;
  dof6_hal_read(&adress1, &temp1, 1);
  dof6_hal_read(&adress2, &temp2, 1);
  temp2 &= 12;
  temp2 = temp2 >> 2;
  temp += temp1;
  temp |= (temp2 << 8);
  if (temp2 == 3 || temp2 == 2)
  {
    temp = ~(temp) + 1;
    temp &= 1023;
    temp = -temp;
  }
  t = temp * 0.061;
  return t;
}

uint8_t  dof6_set_off_gyr_y(float offset)
{
  uint8_t adress1 = OFFSET_3;
  uint8_t adress2 = OFFSET_6;
  int16_t temp;
  int8_t temp1;
  int8_t temp2;
  int8_t t;
  uint8_t status = 0;
  if (offset < -31.25 || offset > 31.25) return status = -1;
  temp = (int16_t) (offset / 0.061);
  temp1 = (int8_t) temp;
  temp2 = (int8_t) (temp >> 8);
  dof6_hal_write(&adress1, &temp1, 1);
  dof6_hal_read(&adress2, &t, 1);
  t &= ~(0x0C);
  t |= (temp2 << 2);
  dof6_hal_write(&adress2, &t, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

float dof6_get_off_gyr_z()
{
  uint8_t adress1 = OFFSET_3;
  uint8_t adress2 = OFFSET_6;
  int8_t temp1 = 0;
  int8_t temp2 = 0;
  int16_t temp = 0;
  float t;
  dof6_hal_read(&adress1, &temp1, 1);
  dof6_hal_read(&adress2, &temp2, 1);
  temp2 &= 0x30;
  temp2 = temp2 >> 4;
  temp += temp1;
  temp |= (temp2 << 8);
  if (temp2 == 3 || temp2 == 2)
  {
    temp = ~(temp) + 1;
    temp &= 1023;
    temp = -temp;
  }
  t = temp * 0.061;
  return t;
}

uint8_t  dof6_set_off_gyr_z(float offset)
{
  uint8_t adress1 = OFFSET_3;
  uint8_t adress2 = OFFSET_6;
  int16_t temp;
  int8_t temp1;
  int8_t temp2;
  int8_t t;
  uint8_t status = 0;
  if (offset < -31.25 || offset > 31.25) return status = -1;
  temp = (int16_t) (offset / 0.061);
  temp1 = (int8_t) temp;
  temp2 = (int8_t) (temp >> 8);
  dof6_hal_write(&adress1, &temp1, 1);
  dof6_hal_read(&adress2, &t, 1);
  t &= ~(0x30);
  t |= (temp2 << 4);
  dof6_hal_write(&adress2, &t, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_gyr_off_en()
{
  return get_bit(OFFSET_6 , 7);
}


void    dof6_set_gyr_off_en(bool set)
{
  if (set)  set_bit(OFFSET_6 , 7);
  else     clear_bit (OFFSET_6 , 7);

}

uint8_t dof6_get_acc_off_en()
{
  return get_bit(OFFSET_6 , 6);
}


void    dof6_set_acc_off_en(bool set)
{
  if (set)  set_bit(OFFSET_6 , 6);
  else     clear_bit (OFFSET_6 , 6);

}



////////////////////////////////////////////////////////////////////////////////

uint16_t dof6_get_step_cnt()
{
  return get_unsinged_data(STEP_CNT_0);
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_min_threshold()
{
  uint8_t adress = STEP_CONF_0;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp = temp >> 3;
  temp &= 3;
  return temp;
}

int8_t  dof6_set_min_threshold(uint8_t min_th)
{
  uint8_t adress = STEP_CONF_0;
  uint8_t  temp;
  uint8_t status = 0;
  dof6_hal_read(&adress, &temp, 1);
  if (min_th < 0 || min_th > 3) return status = -1;
  temp &= ~(0x18);
  temp |= (min_th << 3);
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

uint8_t dof6_get_steptime_min()
{
  uint8_t adress = STEP_CONF_0;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 7;
  return temp;
}

int8_t  dof6_set_steptime_min(uint8_t steptime)
{
  uint8_t adress = STEP_CONF_0;
  uint8_t  temp;
  uint8_t status = 0;
  dof6_hal_read(&adress, &temp, 1);
  if (steptime < 0 || steptime > 7) return status = -1;
  temp &= ~(0x07);
  temp |= steptime;
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

uint8_t dof6_get_step_cnt_en()
{
  return get_bit(STEP_CONF_1 , 3);
}


void    dof6_set_step_cnt_en(bool set)
{
  if (set)  set_bit(STEP_CONF_1 , 3);
  else     clear_bit (STEP_CONF_1 , 3);

}

uint8_t dof6_get_min_step_buf()
{
  uint8_t adress = STEP_CONF_1;
  uint8_t temp = 0;
  dof6_hal_read(&adress, &temp, 1);
  temp &= 7;
  return temp;
}

int8_t  dof6_set_min_step_buf(uint8_t steptime)
{
  uint8_t adress = STEP_CONF_1;
  uint8_t  temp;
  uint8_t status = 0;
  dof6_hal_read(&adress, &temp, 1);
  if (steptime < 0 || steptime > 7) return status = -1;
  temp &= ~(0x07);
  temp |= steptime;
  dof6_hal_write(&adress, &temp, 1);
  return status;
}

////////////////////////////////////////////////////////////////////////////////

void dof6_sensor_config (uint8_t accel_state, uint8_t gyro_state)
{
        uint8_t temp=CMD;
        uint8_t temp_data1 = accel_state;
        uint8_t temp_data2 = gyro_state;
        dof6_hal_write( &temp,&temp_data1,1  );
        delay_ms(100);
        dof6_hal_write( &temp,&temp_data2,1  );
        delay_ms(100);
}

uint8_t  dof6_get_cmd()
{
  uint8_t adress = CMD;
  uint8_t temp;
  dof6_hal_read(&adress, &temp, 1);
  return temp;
}


uint8_t  dof6_set_cmd(uint8_t cmd)
{
  uint8_t status = 0;
  uint8_t adress = CMD;
  uint8_t temp = cmd;
  if (cmd > 255) return status = -1;
  dof6_hal_write(&adress, &temp, 1);
  return status;
}