#ifndef DOF6_HAL_H_HW_
#define DOF6_HAL_H_HW_
/******************************************************************************
* Includes
*******************************************************************************/
#include <stdint.h>
#include <stdbool.h>
#include "6dof_hal.h"
/******************************************************************************
* Preprocessor Constants
*******************************************************************************/
#define BMI160_I2C_ADDRESS                                                      0x68

#define CHIP_ID                  0x00
#define       ERR_REG            0x02
#define       PMU_STATUS         0x03
#define       DATA_0             0x04
#define       DATA_1             0x05
#define       DATA_2             0x06
#define       DATA_3             0x07

#define       DATA_4             0x08
#define       DATA_5             0x09
#define       DATA_6             0x0A
#define       DATA_7             0x0B
#define       DATA_8             0x0C
#define       DATA_9             0x0D
#define       DATA_10            0x0E
#define       DATA_11            0x0F
#define       DATA_12            0x10
#define       DATA_13            0x11
#define       DATA_14            0x12
#define       DATA_15            0x13
#define       DATA_16            0x14

#define       DATA_17            0x15
#define       DATA_18            0x16
#define       DATA_19            0x17
#define       SENSORTIME_0       0x18
#define       SENSORTIME_1       0x19
#define       SENSORTIME_2       0x1A
#define       STATUS             0x1B
#define       INT_STATUS_0       0x1C
#define       INT_STATUS_1       0x1D
#define       INT_STATUS_2       0x1E
#define       INT_STATUS_3       0x1F
#define       TEMPERATURE_0      0x20
#define       TEMPERATURE_1      0x21
#define       FIFO_LENGTH_0      0x22
#define       FIFO_LENGTH_1      0x23
#define       FIFO_DATA          0x24
#define       ACC_CONF           0x40
#define       ACC_RANGE          0x41

#define       GYR_CONF           0x42
#define       GYR_RANGE          0x43
#define       MAG_CONF                     0x44
#define       FIFO_DOWNS                0x45
#define       FIFO_CONFIG_0      0x46
#define       FIFO_CONFIG_1      0x47
#define       MAG_IF_0                     0x4B
#define       MAG_IF_1                      0x4C
#define       MAG_IF_2                     0x4D

#define       MAG_IF_3                    0x4E
#define       MAG_IF_4                    0x4F
#define       INT_EN_0                      0x50
#define       INT_EN_1                      0x51

#define       INT_EN_2           0x52
#define       INT_OUT_CTRL       0x53
#define       INT_LATCH                 0x54
#define       INT_MAP_0          0x55
#define       INT_MAP_1                 0x56
#define       INT_MAP_2          0x57
#define       INT_DATA_0         0x58
#define       INT_DATA_1         0x59
#define       INT_LOWHIGH_0      0x5A
#define       INT_LOWHIGH_1      0x5B
#define       INT_LOWHIGH_2      0x5C
#define       INT_LOWHIGH_3      0x5D
#define       INT_LOWHIGH_4      0x5E
#define       INT_MOTION_0       0x5F
#define       INT_MOTION_1       0x60
#define       INT_MOTION_2       0x61
#define       INT_MOTION_3       0x62
#define       INT_TAP_0          0x63
#define       INT_TAP_1          0x64
#define       INT_ORIENT_0       0x65
#define       INT_ORIENT_1       0x66
#define       INT_FLAT_0         0x67
#define       INT_FLAT_1         0x68
#define       FOC_CONF           0x69
#define       CONF               0x6A
#define       IF_CONF            0x6B
#define       PMU_TRIGGER        0x6C
#define       SELF_TEST          0x6D

#define       NV_CONF            0x70
#define       OFFSET_0           0x71
#define       OFFSET_1           0x72
#define       OFFSET_2           0x73
#define       OFFSET_3           0x74
#define       OFFSET_4           0x75
#define       OFFSET_5           0x76
#define       OFFSET_6           0x77
#define       STEP_CNT_0         0x78
#define       STEP_CNT_1         0x79
#define       STEP_CONF_0        0x7A
#define       STEP_CONF_1        0x7B
#define       CMD                         0x7E

#define  accel_normal                                                          0x11

#define  accel_low_power                                                       0x12

#define  gyro_normal                                                           0x15

#define  gyro_fast                                                             0x17


/******************************************************************************
* Configuration Constants
*******************************************************************************/
typedef enum
 {
         HZ_0_78,
         HZ_1_56,
         HZ_3_125,
         HZ_6_25,
         HZ_12_5,
         HZ_25,
         HZ_50,
         HZ_100,
         HZ_200,
         HZ_400,
         HZ_800,
         HZ_1600

} acc_output_data_rate ;

typedef enum
{
   G_2,
   G_4,
   G_8,
   G_16

}acc_g_range;

typedef enum
 {
         HZ_25_G,
         HZ_50_G,
         HZ_100_G,
         HZ_200_G,
         HZ_400_G,
         HZ_800_G,
         HZ_1600_G,
         HZ_3200_G

} gyr_output_data_rate ;

typedef enum
{
   ARR_2000,
   ARR_1000,
   ARR_500,
   ARR_250,
   ARR_120

}gyr_range;

typedef enum
 {
        M_HZ_0_78,
        M_HZ_1_56,
        M_HZ_3_125,
        M_HZ_6_25,
        M_HZ_12_5,
        M_HZ_25,
        M_HZ_50,
        M_HZ_100,
        M_HZ_200,
        M_HZ_400,
        M_HZ_800

} mag_output_data_rate ;

typedef enum
 {
                AF_HZ_1,
        AF_HZ_2,
        AF_HZ_4,
        AF_HZ_8,
        AF_HZ_16,
        AF_HZ_32,
        AF_HZ_64,
        AF_HZ_128
} acc_fifo_downsapling_ratio;

typedef enum
 {
                GF_HZ_1,
        GF_HZ_2,
        GF_HZ_4,
        GF_HZ_8,
        GF_HZ_16,
        GF_HZ_32,
        GF_HZ_64,
        GF_HZ_128
} gyr_fifo_downsapling_ratio;

typedef enum
 {
        NON_LATCHED,
        TEM_312_5_mis,
        TEM_625_mis,
        TEM_1_25_ms,
        TEM_2_5_ms,
        TEM_5_ms,
        TEM_10_ms,
        TEM_20_ms,
        TEM_40_ms,
        TEM_80_ms,
        TEM_160_ms,
        TEM_320_ms,
        TEM_640_ms,
        TEM_1_28_s,
        TEM_2_56_s,
        LATCHED

} int_latch_interrupt_modes ;

typedef enum
 {
          SKIP_TIME_1_5_s,
          SKIP_TIME_3_s,
          SKIP_TIME_6_s,
          SKIP_TIME_12_s

} int_sig_mot_skip ;

typedef enum
 {
          PROOF_TIME_0_25_s,
          PROOF_TIME_0_5_s,
          PROOF_TIME_1_s,
          PROOF_TIME_2_s

} int_sig_mot_proof;

typedef enum
 {
          SECOND_SHOCK_EVENT_50_s,
             SECOND_SHOCK_EVENT_100_s,
      SECOND_SHOCK_EVENT_150_s,
      SECOND_SHOCK_EVENT_200_s,
      SECOND_SHOCK_EVENT_250_s,
             SECOND_SHOCK_EVENT_375_s,
      SECOND_SHOCK_EVENT_500_s,
      SECOND_SHOCK_EVENT_700_s

} int_tap_dur;

typedef enum
 {
          SYMMETRICAL,
          HIGH_SYMMETRICAL,
          LOW_ASYMMETRICAL

} int_orient_mode ;

typedef enum
 {
                FLAT_STABLE_0_ms,
                FLAT_STABLE_640_ms,
                FLAT_STABLE_1280_ms,
                FLAT_STABLE_2560_ms
} int_flat_hold_time ;

typedef enum
 {
  X_DISABLED,
  X_1_g,
  X_minus_1_g,
  X_0_g
} foc_acc_x ;

typedef enum
 {
  Y_DISABLED,
  Y_1_g,
  Y_minus_1_g,
  Y_0_g
} foc_acc_y ;

typedef enum
 {
  Z_DISABLED,
  Z_1_g,
  Z_minus_1_g,
  Z_0_g
} foc_acc_z ;

typedef enum
{
   RD_1_BYTE,
   RD_2_BYTE,
   RD_6_BYTE,
   RD_8_BYTE

}mag_rd_burst;

/******************************************************************************
* Macros
*******************************************************************************/

/******************************************************************************
* Typedefs
*******************************************************************************/

/******************************************************************************
* Variables
*******************************************************************************/


/******************************************************************************
* Function Prototypes
*******************************************************************************/
#ifdef __cplusplus
extern "C"{
#endif

int8_t dof6_init ( uint8_t address );
////////////////////////////////////////////////////////////////////////////////
//CHIP_ID//

int8_t dof6_get_chip_id();

////////////////////////////////////////////////////////////////////////////////
//ERR_REG//

/*0=no fatal error detected ; 1=fatal error detected */
int8_t dof6_fatal_error_detected();

/*0=no error detected ; 1=error detected */
uint8_t dof6_drop_cmd_err();

/*0=no error detected ; 1,2=error detected ;
3=low-power  mode  and  interrupt  uses pre-filtered data ;
4=ODRs  of  enabled  sensors  in  header-less mode do not match;
5=pre-filtered  data are  used  in  low  powermode ;
-1=reserved ;*/
int8_t dof6_error_detected();

////////////////////////////////////////////////////////////////////////////////
//PMU_STATUS//

/*0=normal mode ; 1=low power ; -1=suspended ;*/
int8_t dof6_acc_power_mode_status();

/*0=normal mode ; 1=low power ; -1=suspended ; 2=fast strat-up ;*/
int8_t dof6_gyr_power_mode_status();

/*0=normal mode ; 1=low power ; -1=suspended ;*/
int8_t dof6_mag_power_mode_status();

////////////////////////////////////////////////////////////////////////////////
//DATA//

/*gets data*/
/*acc g*/
int16_t dof6_get_mag_x();

int16_t dof6_get_mag_y();

int16_t dof6_get_mag_z();

int16_t dof6_get_rhall();

float dof6_get_gyr_x();

float dof6_get_gyr_y();

float dof6_get_gyr_z();

float dof6_get_acc_x();

float dof6_get_acc_y();

float dof6_get_acc_z();

////////////////////////////////////////////////////////////////////////////////
//SENSORTIME//

/*gets sensortime in ms.The sensortime is unique for approx 10 min and 54 seconds*/
float dof6_get_sensortime();

////////////////////////////////////////////////////////////////////////////////
//STATUS//

/* 1=data is ready ; 0=data is not ready*/
uint8_t dof6_data_ready_acc();

uint8_t dof6_data_ready_gyr();

uint8_t dof6_data_ready_mag();

uint8_t dof6_data_ready_nvm();

uint8_t dof6_data_ready_foc();

/*0= indicates no manual magnetometer interface operation
1= indicates a manual magnetometer interface operation triggered via MAG_IF[2] or MAG_IF[3]*/
uint8_t mag_man_op ();

/*0 = gyroscope self-test is running or failed.
1 = gyroscope self-test completed successfully.*/
uint8_t gyr_self_test_ok ();

////////////////////////////////////////////////////////////////////////////////
//INT_STATUS_0//

/*0=interrupt is inactive ; 1=interrupt is active ;*/

uint8_t dof6_get_step_int();

uint8_t dof6_get_sigmot_int();

uint8_t dof6_get_anym_int();

uint8_t dof6_get_pmu_trigger_int();

uint8_t dof6_get_d_tap_int();

uint8_t dof6_get_s_tap_int();

uint8_t dof6_get_orient_int();

uint8_t dof6_get_flat_int();

////////////////////////////////////////////////////////////////////////////////
//INT_STATUS_1//

/*0=interrupt is inactive ; 1=interrupt is active ;*/

uint8_t dof6_get_highg_int();

uint8_t dof6_get_lowg_int();

uint8_t dof6_get_drdy_int();

uint8_t dof6_get_ffull_int();

uint8_t dof6_get_fwm_int();

uint8_t dof6_get_nomo_int();

////////////////////////////////////////////////////////////////////////////////
//INT_STATUS_2//

/*0=interrupt is inactive ; 1=interrupt is active ;*/

uint8_t dof6_get_anym_first_x();

uint8_t dof6_get_anym_first_y();

uint8_t dof6_get_anym_first_z();

uint8_t dof6_get_anym_sign();

uint8_t dof6_get_tap_first_x();

uint8_t dof6_get_tap_first_y();

uint8_t dof6_get_tap_first_z();

uint8_t dof6_get_tap_sign();

////////////////////////////////////////////////////////////////////////////////
//INT_STATUS_3//

/*high-g  interrupt: 1=triggered  by, or 0=not triggered by x,y,z-axis*/
uint8_t dof6_get_high_first_x();

uint8_t dof6_get_high_first_y();

uint8_t dof6_get_high_first_z();

/*sign  of  acceleration  signal  that  triggered  high-g interrupt was
0=positive, 1=negative ;*/
uint8_t dof6_get_high_sign();

/*orientation value of xx-y-plane:
00=portrait upright;01=portrait upside down;10=landscape left;11=landscape right;*/
uint8_t dof6_get_orient();

/*Orientation  value  of  z-axis:
0=upward  looking,or 1=downward looking;*/
uint8_t dof6_get_orient_2();

/*device  is  in 1= flat , or 0=non  flat  position ;*/
uint8_t dof6_get_flat();

////////////////////////////////////////////////////////////////////////////////
//TEMPERATURE//

/*gets a sensor temperature*/
float dof6_get_sensor_temperature();

////////////////////////////////////////////////////////////////////////////////
//FIFO_LENGTH//

/*shows current fill level of FIFO buffer*/
uint16_t dof6_get_fifo_lenght();


////////////////////////////////////////////////////////////////////////////////
//FIFO_DATA//

/*data format depends on the setting of Register(0x46-0x47) FIFO_CONFIG;*/
uint16_t dof6_get_fifo_data();

////////////////////////////////////////////////////////////////////////////////
//ACC_CONF//

/*sets undersampling parameter*/
void dof6_set_acc_undersampling(bool set);

/*gets undersampling parameter*/
uint8_t dof6_get_acc_undersampling();

/*bandwidth  parameter  determines  filter  configuration  (acc_us=0)  and  averaging
for undersampling mode (acc_us=1)*/
uint8_t dof6_get_acc_bandwidth() ;

int8_t dof6_set_acc_bandwidth(uint8_t bw);

/*gets the output data rate in Hz.It is defened as 100/2^(8-value(acc_odr)) ;*/
float dof6_get_acc_output_data_rate();

/*sets the output data rate in Hz.It is defened as 100/2^(8-value(acc_odr)) ;*/
void dof6_set_acc_output_data_rate(acc_output_data_rate acc_odr);

////////////////////////////////////////////////////////////////////////////////
//ACC_RANGE//

/*gets accelerometer g-range:
0011= \B12g range ;0101= \B14g range ;1000= \B18g range ;1100= \B116g range;all other settings= \B12g range ;*/
uint8_t dof6_get_acc_g_range();

/*sets accelerometer g-range:
0011= \B12g range ;0101= \B14g range ;1000= \B18g range ;1100= \B116g range;all other settings= \B12g range ;*/
void dof6_set_acc_g_range(acc_g_range acc_r);


////////////////////////////////////////////////////////////////////////////////
//GYR_CONF//

/*the gyroscope bandwidth coefficient defines the 3 dB cutoff frequency of the low pass
filter for the sensor data*/
uint8_t dof6_get_gyr_bandwidth();

int8_t dof6_set_gyr_bandwidth(uint8_t bw);

/*gets the  output  data  rate  of  the  gyroscope  in  the  sensor.The output data rate in Hz is given by 100/2^(8-value(gyr_odr))*/
float dof6_get_gyr_output_data_rate();

/*sets the  output  data  rate  of  the  gyroscope  in  the  sensor.The output data rate in Hz is given by 100/2^(8-value(gyr_odr))*/
void dof6_set_gyr_output_data_rate(gyr_output_data_rate gyr_odr);


////////////////////////////////////////////////////////////////////////////////
//GYR_RANGE//

/*gets gyroscope angular rate range and resolution:
000= \B12000\B0/s ;001= \B11000\B0/s ;010= \B1500\B0/s ;011= \B1250\B0/s;100= \B1125\B0/s ;all other settings are reserved*/
uint32_t dof6_get_gyr_range();

/*sets gyroscope angular rate range and resolution:
000= \B12000\B0/s ;001= \B11000\B0/s ;010= \B1500\B0/s ;011= \B1250\B0/s;100= \B1125\B0/s ;all other settings are reserve*/

void dof6_set_gyr_range(gyr_range gyr_r);

////////////////////////////////////////////////////////////////////////////////
//MAG_CONF//

/*gets the output data rate of the magnetometer in the sensor.The output data rate in Hz is given by 100/2^(8-value(mag_odr<3:0>))*/
uint8_t dof6_get_mag_output_data_rate();

/*sets the output data rate of the magnetometer in the sensor.The output data rate in Hz is given by 100/2^(8-value(mag_odr<3:0>))*/
void dof6_set_mag_output_data_rate(mag_output_data_rate mag_odr);

////////////////////////////////////////////////////////////////////////////////
//FIFO_DOWNS//

/*used to configure the down sampling ratios of the accel and gyro data for FIFO.*/
/*The downsampling ratio for the gyroscope and accelerometer data are given by 2^Val(acc || gyr _fifo_downs)*/
/*[acc,gyr]_fifo_filt_data=0 selects pre-filtered (filtered) data for the FIFO */
uint8_t dof6_get_acc_fifo_filt_data();

void dof6_set_acc_fifo_filt_data(bool set);

uint16_t dof6_get_acc_fifo_downs ();

void dof6_set_acc_fifo_downs (acc_fifo_downsapling_ratio acc_fdr);

uint8_t dof6_get_gyr_fifo_filt_data();

void dof6_set_gyr_fifo_filt_data(bool set);

uint16_t dof6_get_gyr_fifo_downs ();

void dof6_set_gyr_fifo_downs (gyr_fifo_downsapling_ratio gyr_fdr);

////////////////////////////////////////////////////////////////////////////////
//FIFO_CONFIG_0//

/*fifo_water_mark defines the FIFO watermark level. An interrupt will be
generated,   when   the   number   of   entries   in   the   FIFO   exceeds
fifo_water_mark.*/

uint8_t   dof6_get_fifo_water_mark ();

uint8_t dof6_set_fifo_water_mark (uint8_t fifo_water_mark);

////////////////////////////////////////////////////////////////////////////////
//FIFO_CONFIG_1//

/*0=no data are stored in FIFO,1=data are stored in FIFO(all 3 axes)*/
uint8_t dof6_get_fifo_gyr_en();

uint8_t dof6_get_fifo_acc_en() ;

uint8_t dof6_get_fifo_mag_en();

/*1=each frame contains a header, 0=the frame format is headerless*/
uint8_t dof6_get_fifo_header_en();

/*1(0) enables (disables) FIFO tag (interrupt)*/
uint8_t dof6_get_fifo_tag_int1_en();

uint8_t dof6_get_fifo_tag_int2_en();

/*1(0) returns (does not return) a sensortime frame after the last valid frame
when more data are read than valid frames are in the FIFO*/
uint8_t dof6_get_fifo_time_en();

void dof6_set_fifo_gyr_en(bool set);

void dof6_set_fifo_acc_en(bool set);

void dof6_set_fifo_mag_en(bool set);

void dof6_set_fifo_header_en(bool set);

void dof6_set_fifo_tag_int1_en(bool set);

void dof6_set_fifo_tag_int2_en(bool set);

void dof6_set_fifo_time_en(bool set);

////////////////////////////////////////////////////////////////////////////////
//MAG_IF_0//

/*register for indirect addressing of the magnetometer connected to the magnetometer interface*/
/*this register allows read and write operations on the magnetometer register map*/
uint8_t dof6_get_mag_i2c_adress();

uint8_t dof6_set_mag_i2c_adress(uint8_t adr);

////////////////////////////////////////////////////////////////////////////////
//MAG_IF_1//

/*Enable magnetometer register access on MAG_IF[2] (read operations) or MAG_IF[3] (write operations). */
uint8_t dof6_get_mag_manual_en();

void dof6_set_mag_manual_en(bool set);

/*trigger-readout offset in units 2.5 ms*/
uint8_t dof6_get_mag_offset();

void dof6_set_mag_offset(uint8_t offset);

/*Data length of read burst operation, which reads out data from magnetometer(0b00=1,0b01=2,0b10=6,0b11=8 byte)*/
uint8_t  dof6_get_mag_rd_burst();

void dof6_set_mag_rd_burst(mag_rd_burst rd);

////////////////////////////////////////////////////////////////////////////////
//MAG_IF_2//

/*address to read*/
uint8_t  dof6_get_mag_read_adress();

uint8_t dof6_set_mag_read_adress(uint8_t adr);

////////////////////////////////////////////////////////////////////////////////
//MAG_IF_3//

/*address to write*/
uint8_t  dof6_get_mag_write_adress();

uint8_t dof6_set_mag_write_adress(uint8_t adr);

////////////////////////////////////////////////////////////////////////////////
//MAG_IF_4//

/*data to write*/
uint8_t  dof6_get_mag_write_data();

uint8_t dof6_set_mag_write_adress(uint8_t adr);

////////////////////////////////////////////////////////////////////////////////
//INT_EN_0//

/*0= disables the interrupt, 1= enables it.*/
uint8_t dof6_get_int_flat_en();

void dof6_set_int_flat_en(bool set);

uint8_t dof6_get_int_orient_en();

void dof6_set_int_orient_en(bool set);

uint8_t dof6_get_int_s_tap_en();

void dof6_set_int_s_tap_en(bool set);

uint8_t dof6_get_int_d_tap_en();

void dof6_set_int_d_tap_en(bool set);

uint8_t dof6_get_int_anymo_z_en();

void dof6_set_int_anymo_z_en(bool set);

uint8_t dof6_get_int_anymo_y_en();

void dof6_set_int_anymo_y_en(bool set);

uint8_t dof6_get_int_anymo_x_en();

void dof6_set_int_anymo_x_en(bool set);

////////////////////////////////////////////////////////////////////////////////
//INT_EN_1//

/*0= disables the interrupt, 1= enables it.*/
uint8_t dof6_get_int_fwm_en();

void dof6_set_int_fwm_en(bool set);

uint8_t dof6_get_int_ffull_en();

void dof6_set_int_ffull_en(bool set);

uint8_t dof6_get_int_drdy_en();

void dof6_set_int_drdy_en(bool set);

uint8_t dof6_get_int_low_en();

void dof6_set_int_low_en(bool set);

uint8_t dof6_get_int_highz_en();

void dof6_set_int_highz_en(bool set);

uint8_t dof6_get_int_highy_en();

void dof6_set_int_highy_en(bool set);

uint8_t dof6_get_int_highx_en();

void dof6_set_int_highx_en(bool set);

////////////////////////////////////////////////////////////////////////////////
//INT_EN_2//

/*0= disables the interrupt, 1= enables it.*/
uint8_t dof6_get_int_step_det_en();

void dof6_set_int_step_det_en(bool set);

uint8_t dof6_get_int_nomoz_en();

void dof6_set_int_nomoz_en(bool set);

uint8_t dof6_get_int_nomoy_en();

void dof6_set_int_nomoy_en(bool set);

uint8_t dof6_get_int_nomox_en();

void dof6_set_int_nomox_en(bool set);

////////////////////////////////////////////////////////////////////////////////
//INT_OUT_CTRL//

/*0=output disabled,or 1=output enabled for INT2 pin ;*/
uint8_t dof6_get_int2_output_en();

void dof6_set_int2_output_en(bool set);

/*0=push-pull,or 1=open drain behavior for INT2 pin ;*/
uint8_t dof6_get_int2_od();

void dof6_set_int2_od(bool set);

/*0=active low,or 1=active high level for INT2 pin*/
uint8_t dof6_get_int2_lvl();

void dof6_set_int2_lvl(bool set);

/*1(0) is edge (level) triggered for INT2 pin*/
uint8_t dof6_get_int2_edge_crtl();

void dof6_set_int2_edge_crtl(bool set);

/*0=output disabled,or 1=output enabled for INT1 pin ;*/
uint8_t dof6_get_int1_output_en();

void dof6_set_int1_output_en(bool set);

/*0=push-pull,or 1=open drain behavior for INT1 pin ;*/
uint8_t dof6_get_int1_od();

void dof6_set_int1_od(bool set);

/*0=active low,or 1=active high level for INT1 pin*/
uint8_t dof6_get_int1_lvl();

void dof6_set_int1_lvl(bool set);

/*1(0) is edge (level) triggered for INT1 pin*/
uint8_t dof6_get_int1_edge_crtl();

void dof6_set_int1_edge_crtl(bool set);

////////////////////////////////////////////////////////////////////////////////
//INT_LATCH//

/*0=input disabled,or 1=input enabled for INT2 pin ;*/
uint8_t dof6_get_int2_input_en();

void dof6_set_int2_input_en(bool set);

/*0=input disabled,or 1=input enabled for INT1 pin ;*/
uint8_t dof6_get_int1_input_en();

void dof6_set_int1_input_en(bool set);

/*latched/non-latched/temporary interrupt modes.Gets and sets values which are defined by
0.3125*pow(2,val(int_latch)-1) in miliseconds;0000=not latched,1111= latched*/
float dof6_get_int_latch();

void dof6_set_int_latch(int_latch_interrupt_modes int_latch);

////////////////////////////////////////////////////////////////////////////////
//INT_MAP_0//

/*Controls which interrupt signals are mapped to the INT1 and INT2 pin.*/
/*1= mapping is active,0= mapping is inactive.*/
uint8_t dof6_get_int1_flat();

void    dof6_set_int1_flat(bool set);

uint8_t dof6_get_int1_orient();

void   dof6_set_int1_orient(bool set);

uint8_t dof6_get_int1_s_tap();

void   dof6_set_int1_s_tap(bool set);

uint8_t dof6_get_int1_d_tap();

void    dof6_set_int1_d_tap(bool set);

uint8_t dof6_get_int1_nomotion();

void    dof6_set_int1_nomotion(bool set);

uint8_t dof6_get_int1_anymotion();

void    dof6_set_int1_anymotion(bool set);

uint8_t dof6_get_int1_highg();

void   dof6_set_int1_highg(bool set);

uint8_t dof6_get_int1_lowg_step();

void   dof6_set_int1_lowg_step(bool set);

////////////////////////////////////////////////////////////////////////////////
//INT_MAP_1//

/*Controls which interrupt signals are mapped to the INT1 and INT2 pin.*/
/*1= mapping is active,0= mapping is inactive.*/
uint8_t dof6_get_int1_drdy();

void  dof6_set_int1_drdy(bool set);

uint8_t dof6_get_int1_fwm();

void  dof6_set_int1_fwm(bool set);

uint8_t dof6_get_int1_ffull();

void  dof6_set_int1_ffull(bool set);

uint8_t dof6_get_int1_pmu_trig();

void  dof6_set_int1_pmu_trig(bool set);

uint8_t dof6_get_int2_drdy();

void  dof6_set_int2_drdy(bool set);

uint8_t dof6_get_int2_fwm();

void  dof6_set_int2_fwm(bool set);

uint8_t dof6_get_int2_ffull();

void  dof6_set_int2_ffull(bool set);

uint8_t dof6_get_int2_pmu_trig();

void    dof6_set_int2_pmu_trig(bool set);

////////////////////////////////////////////////////////////////////////////////
//INT_MAP_2//

/*Controls which interrupt signals are mapped to the INT1 and INT2 pin.*/
/*1= mapping is active,0= mapping is inactive.*/
uint8_t dof6_get_int2_flat();

void  dof6_set_int2_flat(bool set);

uint8_t dof6_get_int2_orient();

void    dof6_set_int2_orient(bool set);

uint8_t dof6_get_int2_s_tap();

void  dof6_set_int2_s_tap(bool set);

uint8_t dof6_get_int2_d_tap();

void   dof6_set_int2_d_tap(bool set);

uint8_t dof6_get_int2_nomotion();

void  dof6_set_int2_nomotion(bool set);

uint8_t dof6_get_int2_anymotion();

void  dof6_set_int2_anymotion(bool set);

uint8_t dof6_get_int2_highg();

void  dof6_set_int2_highg(bool set);

uint8_t dof6_get_int2_lowg_step();

void  dof6_set_int2_lowg_step(bool set);

////////////////////////////////////////////////////////////////////////////////
//INT_DATA_0//

/*0(1) selects filtered (pre-filtered) data for the interrupt engine for the low and high g interrupts.*/
uint8_t dof6_get_int_low_high_src();

void  dof6_set_int_low_high_src(bool set);

/*0(1) selects filtered (pre-filtered) data for the interrupt engine for the single and double tap interrupts.*/
uint8_t dof6_get_int_tap_src();

void  dof6_set_int_tap_src(bool set);

////////////////////////////////////////////////////////////////////////////////
//INT_DATA_1//

/*0(1) selects filtered (pre-filtered) data for the interrupt engine for the nomotion and anymotion interrupts.*/
uint8_t dof6_get_int_motion_src();

void  dof6_set_int_motion_src(bool set);

////////////////////////////////////////////////////////////////////////////////
//INT_LOWHIGH_0//

/*gets and sets the delay time definition for the low-g interrupt.*/
/*low-g interrupt trigger delay according to [int_low_dur<7:0>+ 1]\952.5 ms in a range from 2.5 ms to 640ms*/
float dof6_get_int_low_dur();

uint8_t dof6_set_int_low_dur(float dur);

////////////////////////////////////////////////////////////////////////////////
//INT_LOWHIGH_1//

/* gets and sets the threshold definition for the low-g interrupt*/
/*gets and sets low-g interrupt trigger threshold according to Val(int_low_th<7:0>)\957.81 mg for Val(int_low_th<7:0>)>0 and
3.91 mg for Val(int_low_th<7:0>)=0.The range of the threshold is from 3.91 mg to 2.000 g;*/
float dof6_get_int_low_th();

uint8_t dof6_set_int_low_th(float dur);

////////////////////////////////////////////////////////////////////////////////
//INT_LOWHIGH_2//

/*gets and sets hysteresis of high-g interrupt according to Val(int_high_hy<1:0>)\B7125mg (2-g range),
Val(int_high_hy<1:0>)\B7250mg (4-g range), Val(int_high_hy<1:0>)\B7500mg (8-g range),or Val(int_high_hy<1:0>)\B71000mg (16-g range)*/
float dof6_get_int_high_hy();

uint8_t dof6_set_int_high_hy(float dur);

/*select low-g interrupt 0=single-axis mode,or 1=axis-summing mode*/
uint8_t dof6_get_int_low_mode();

void  dof6_set_int_low_mode(bool set);

/*gets and sets hysteresis of low-g interrupt according to int_low_hy<1:0>\B7125mg independent of the selected accelerometer g-range*/
float dof6_get_int_low_hy();

uint8_t dof6_set_int_low_hy(float dur);

////////////////////////////////////////////////////////////////////////////////
//INT_LOWHIGH_3//

/*gets and sets the delay time definition for the high-g interrupt.*/
/*gets and sets high-g interrupt trigger delay according to [int_high_dur<7:0>+ 1]\952.5ms in a range from
2.5ms to 640ms; the default corresponds to a delay of 30ms.*/
float dof6_get_int_high_dur();

uint8_t dof6_set_int_high_dur(float dur);

////////////////////////////////////////////////////////////////////////////////
//INT_LOWHIGH_4//

/* gets and sets the threshold definition for the high-g interrupt.*/
/*gets and sets hreshold of high-g interrupt according to Val(int_high_th<7:0>)\B77.81mg (2grange),
Val(int_high_th<7:0>)\B715.63mg (4g range), Val(int_high_th<7:0>)\B731.25mg (8g range),or Val(int_high_th<7:0>)\B762.5mg (16g range).
For  Val(int_high_th<7:0>)=0,the thresholds are defined by 3.91mg(2g range),7.81mg(4g range),15.63mg(8g range),31.25mg(16g range)*/
float dof6_get_int_high_th();

uint8_t dof6_set_int_high_th(float dur);

////////////////////////////////////////////////////////////////////////////////
//INT_MOTION_0//

/*Function depends on whether the slow-motion or no-motion interrupt function has been selected.
If the slow-motion interrupt function has been enabled (int_no_mot_sel=0) then [int_slo_no_mot_dur<1:0>+1]
consecutive slope data points must be above the slow/no-motion threshole(int_slo_no_mot_th) for the slow-/no-motion interrupt to trigger.
If the no-motion  interrupt  function  has  been  enabled  (int_no_mot_sel = 1) then int_slo_no_motion_dur<5:0> defines
the time for which no slope data points must exceed the slow/no-motion threshold (int_slo_no_mot_th) for the slow/no-motion interrupt to trigger.
The delay time in seconds may be calculated according with the following equation:
int_slo_no_mot_dur<5:4>=00: [int_slo_no_mot_dur<3:0> + 1] \B7 1.28s-> [1.28\9620.48] s;
int_slo_no_mot_dur<5:4>=01: [int_slo_no_mot_dur<3:0> + 5] \B7 5.12s-> [25.6\96102.4] s;
int_slo_no_mot_dur<5>=1 :[int_slo_no_mot_dur<4:0> + 11] \B7 10.24s-> [112.64\96430.08] s;*/
float dof6_get_int_slo_nomo_dur();

int8_t dof6_set_int_slo_nomo_dur(float dur);

/*gets and sets slope interrupt triggers if [int_anym_dur<1:0>+1] consecutive slope data
points are above the slope interrupt threshold int_anym_th<7:0>*/
uint8_t  dof6_get_int_anym_dur();

int8_t dof6_set_int_anym_dur(uint8_t dur);

////////////////////////////////////////////////////////////////////////////////
//INT_MOTION_1//

/*gets and sets threshold of the any-motion interrupt.It is range-dependent and defined
as a sample-to-sample difference according to int_anym_th<7:0>\B73.91mg(2-g range),
int_anym_th<7:0>\B77.81mg(4-g range),int_anym_th<7:0>\B715.63mg(8-g range),int_anym_th<7:0>\B731.25mg (16-g range)
For int_anym_th<7:0>=0x00 the threshold is 1.95mg(2g range)/3.91mg(4g range)/7.81mg(8g range)/15.63mg(16g range*/
float dof6_get_int_anymo_th();

uint8_t dof6_set_int_anymo_th(float th);

////////////////////////////////////////////////////////////////////////////////
//INT_MOTION_2//

/*gets and sets threshold of slow/no-motion interrupt.It is range-dependent and defined as a
sample-to-sample difference according to int_slo_no_mot_th<7:0>\B73.91mg(2-g range),
int_slo_no_mot_th<7:0>\B77.81mg(4-g range),int_slo_no_mot_th<7:0>\B715.63mg(8-g range),
int_slo_no_mot_th<7:0>\B731.25mg(16-g range).For int_slo_no_mot_th<7:0>=0x00 the threshold is
1.95mg(2g  range)/3.91mg(4g  range)/7.81mg(8g range)/15.63mg(16g range)*/
float dof6_get_int_slo_nomo_th();

uint8_t dof6_set_int_slo_nomo_th(float th);

////////////////////////////////////////////////////////////////////////////////
//INT_MOTION_3//

/*1(0) selects no-motion(slow-motion) interrupt function*/
uint8_t dof6_get_int_slo_nomo_sel();

void  dof6_set_int_slo_nomo_sel(bool set);

/* 1(0) selects significant(anymotion) interrupt function*/
uint8_t dof6_get_int_sig_mot_sel();

void  dof6_set_int_sig_mot_sel(bool set);

/*gets and sets the skip time of the significant motion interrupt:0=1.5s, 1=3s, 2=6s, 3=12s*/
float dof6_get_int_sig_mot_skip();

int8_t   dof6_set_int_sig_mot_skip(int_sig_mot_skip time);

/*gets and sets the proof time of the significant motion interrupt: 0=0.25s, 1=0.5s, 2=1s,3=2s*/
float dof6_get_int_sig_mot_proof();

int8_t   dof6_set_int_sig_mot_proof(int_sig_mot_skip time);

////////////////////////////////////////////////////////////////////////////////
//INT_TAP_0//

/*gets and sets a tap quiet duration of 0=30ms,1=20ms*/
uint8_t dof6_get_int_tap_quiet();

void   dof6_set_int_tap_quiet(bool set);

/*gets adn sets a tap shock duration of 0=50ms,1=75ms*/
uint8_t dof6_get_int_tap_shock();

void  dof6_set_int_tap_shock(bool set);

/*gets and sets the length of the time window for the second shock event for double
tap detection according to
000=50 ms,001=100 ms,010=150 ms,011=200 ms,100=250 ms,101=375 ms,110=500 ms,111=700 ms.*/
uint16_t dof6_get_int_tap_dur();

int8_t   dof6_set_int_tap_dur(int_tap_dur time);

////////////////////////////////////////////////////////////////////////////////
//INT_TAP_1//

/*gets and sets hreshold of the single/double-tap interrupt corresponding to an acceleration
difference of val(int_tap_th<3:0>)\B762.5mg (2g-range), val(int_tap_th<3:0>)\B7125mg (4g-range),
val(int_tap_th<3:0>) \B7 250mg (8g-range),and val(int_tap_th<3:0>)\B7 500mg (16g-range).Int_tap_th<3:0>=0b0000,
val(int_tap_th<3:0>)=0.5 is used in the above formulas.*/
float dof6_get_int_tap_th();

uint8_t dof6_set_int_tap_th(float th);

////////////////////////////////////////////////////////////////////////////////
//INT_ORIENT_0//

/*gets and sets the hysteresis of the orientation interrupt; 1 LSB corresponds to
62.5 mg irrespective of the selected g-range*/
float dof6_get_int_orient_hy();

uint8_t dof6_set_int_orient_hy(float th);

/*gets and sets the blocking mode that is used for the generation of the orientation interrupt.The following blocking modes are available:
00=no blocking,01=theta blocking or acceleration in any axis > 1.5g,10=,theta blocking or acceleration slope in any axis > 0.2 g
or acceleration in any axis > 1.5g, 11=theta blocking or acceleration slope in any axis > 0.4 g or
acceleration in any axis > 1.5g and value of orient is not stable for at least 100ms*/
uint8_t dof6_get_int_orient_blocking();

int8_t   dof6_set_int_orient_blocking(uint8_t block);

/*gets and sets the thresholds for switching between the different orientations.The settings:
00=symmetrical,01=high-asymmetrical,10=low-asymmetrical,11=symmetrical.*/
uint8_t dof6_get_int_orient_mode();

int8_t   dof6_set_int_orient_mode(int_orient_mode mode);

////////////////////////////////////////////////////////////////////////////////
//INT_ORIENT_1//

/*axes remapping of x-, y- and z-axis*/
uint8_t dof6_get_int_orient_axes_ex();

void  dof6_set_int_orient_axes_ex(bool set);

/*gets and sets change of up/down-bit 1=generates an orientation interrupt,0=is ignored and will not generate an orientation interrupt*/
uint8_t dof6_get_int_orient_ud_en();

void  dof6_set_int_orient_ud_en(bool set);

/*gets and sets a blocking angle between 0\B0 and 44.8\B0 */
float dof6_get_int_orient_theta();

int8_t dof6_set_int_orient_theta(float orient);

////////////////////////////////////////////////////////////////////////////////
//INT_FLAT_0//

/*gets and sets threshold for detection of flat position in range from 0\B0 to 44.8\B0 */
float dof6_get_int_flat_theta();

int8_t dof6_set_int_flat_theta(float flat);

////////////////////////////////////////////////////////////////////////////////
//INT_FLAT_1//

/*gets and sets delay  time  for  which  the  flat  value  must  remain  stable  for  the  flat
interrupt  to  be  generated:00=0ms,01=640ms,10=1280 ms,11=2560 ms*/
uint16_t dof6_get_int_flat_hold_time();

int8_t  dof6_set_int_flat_hold_time(int_flat_hold_time time);

/*sets and gets flat interrupt hysteresis*/
uint8_t dof6_get_int_flat_hy();

int8_t dof6_set_int_flat_hy(uint8_t flat_hy);

////////////////////////////////////////////////////////////////////////////////
//FOC_CONF//

/*sets and gets fast offset compensation for all three axis of the gyro*/
uint8_t dof6_get_foc_gyr_en();

/*sets and gets offset compensation target value for x,y,z-axis is
00=disabled,01=+1 g,10=-1 g,or 11=0 g*/
void  dof6_set_foc_gyr_en(bool set);

int8_t dof6_get_foc_acc_x();

int8_t  dof6_set_foc_acc_x(foc_acc_x offset);

int8_t dof6_get_foc_acc_y();

int8_t dof6_set_foc_acc_y(foc_acc_y offset);

int8_t dof6_get_foc_acc_z();

int8_t   dof6_set_foc_acc_z(foc_acc_y offset);

////////////////////////////////////////////////////////////////////////////////
//CONF//

/*1(0) enables(disables) that the NVM may be programmed*/
uint8_t dof6_get_nvm_prog_en();

void  dof6_set_nvm_prog_en(bool set);

////////////////////////////////////////////////////////////////////////////////
//IF_CONF//

/*select 0=4-wire SPI,or 1=3-wire SPI mode for primary */
uint8_t dof6_get_spi3();

void  dof6_set_spi3(bool set);

/*gents and sets mode:
00: primary interface: autoconfig / secondary interface: off
01: Primary interface:I2C / secondary interface:OIS
10: Primary interface:autoconfig / secondary interface:Magnetometer
11: reserved*/
uint8_t dof6_get_if_mode();

int8_t dof6_set_if_mode(uint8_t if_mode);

////////////////////////////////////////////////////////////////////////////////
//PMU_TRIGGER//

/*1(0) triggers an interrupt, when a gyro wakeup is triggered*/
uint8_t dof6_get_wakeup_int();

void  dof6_set_wakeup_int(bool set);

/*1(0) transitions to suspend (fast start-up) state*/
uint8_t dof6_get_gyr_sleep_state();

void  dof6_set_gyr_sleep_state(bool set);

uint8_t dof6_get_gyr_wakeup_trigg();

int8_t dof6_set_gyr_wakeup_trigg(uint8_t gyr_wakeup);

uint8_t dof6_get_gyr_sleep_trigger();

int8_t dof6_set_gyr_sleep_trigger(uint8_t gyr_sleep);

////////////////////////////////////////////////////////////////////////////////
//SELF_TEST//

/*starts self-test of the gyroscope.The result can be obtained from Register (0x1B) STATUS*/
uint8_t dof6_get_gyr_self_test_enable();

void  dof6_set_gyr_self_test_enable(bool set);

/*gets and sets amplitude of the selftest deflection  1=high,default value is low (0)*/
uint8_t dof6_get_acc_self_test_amp();

void  dof6_set_acc_self_test_amp(bool set);

/*gets and sets sign of self-test excitation as 1=positive, or 0=negative*/
uint8_t dof6_get_acc_self_test_sign();

void  dof6_set_acc_self_test_sign(bool set);

/*starts  self-test of the accel:00=self-test disabled,01=self-test enabled.The result can be obtained from Register (0x1B) STATUS*/
uint8_t dof6_get_acc_self_test_enable();

void  dof6_set_acc_self_test_enable(bool set);

////////////////////////////////////////////////////////////////////////////////
//NV_CONF//

/*gets and sets I2C nterface mode.
1=enable,or 0=disables the watchdog at the SDI pin*/
uint8_t dof6_get_i2c_wdt_en();

void  dof6_set_i2c_wdt_en(bool set);

/*gets and sets an I2C watchdog timer period of 0=1ms,or 1=50ms*/
uint8_t dof6_get_i2c_wdt_sel();

void  dof6_set_i2c_wdt_sel(bool set);

/*disable  the  I2C  and  only  enable  SPI  for  the  primary interface,when it is in autoconfig if_mode.*/
uint8_t dof6_get_spi_en();

void  dof6_set_spi_en(bool set);

////////////////////////////////////////////////////////////////////////////////
//OFFSET_0//

/*gets and sets the offset compensation values for accelerometer.The  offset  of  the  accelerometer  off_acc_[xyz] is a
8bit two-complement number  in  units  of 3.9mg independent of the range selected for the accelerometer. */
float dof6_get_off_acc_x();

uint8_t  dof6_set_off_acc_x(float offset);

////////////////////////////////////////////////////////////////////////////////
//OFFSET_1//

float dof6_get_off_acc_y();

uint8_t  dof6_set_off_acc_y(float offset);

////////////////////////////////////////////////////////////////////////////////
//OFFSET_2//

float dof6_get_off_acc_z();

uint8_t  dof6_set_off_acc_z(float offset);

////////////////////////////////////////////////////////////////////////////////
//OFFSET_3//

/*gets and sets the offset compensation values for gyroscope.The  offset  of  the  gyroscope  off_gyr_[xyz] is a
10bit two-complement number  in  units of 0.061\B0/s. */
float dof6_get_off_gyr_x();

uint8_t  dof6_set_off_gyr_x(float offset);

////////////////////////////////////////////////////////////////////////////////
//OFFSET_4//

float dof6_get_off_gyr_y();

uint8_t  dof6_set_off_gyr_y(float offset);

////////////////////////////////////////////////////////////////////////////////
//OFFSET_5//

float dof6_get_off_gyr_z();

uint8_t  dof6_set_off_gyr_z(float offset);

////////////////////////////////////////////////////////////////////////////////
//OFFSET_6//

/*1=enable an offset,0=disable an offset*/
uint8_t dof6_get_gyr_off_en();

void  dof6_set_gyr_off_en(bool set);

uint8_t dof6_get_acc_off_en();

void  dof6_set_acc_off_en(bool set);

////////////////////////////////////////////////////////////////////////////////
//STEP_CNT_0//

/*gets and sets number of steps counted since last POR or step counter reset*/
uint16_t dof6_get_step_cnt();

////////////////////////////////////////////////////////////////////////////////
//STEP_CONF_0//

uint8_t dof6_get_min_threshold();

int8_t  dof6_set_min_threshold(uint8_t min_th);

/*gets and sets minimal detectable step time with offset 1*/
uint8_t dof6_get_steptime_min();

int8_t  dof6_set_steptime_min(uint8_t steptime);

////////////////////////////////////////////////////////////////////////////////
//STEP_CONF_1//

uint8_t dof6_get_step_cnt_en();

void  dof6_set_step_cnt_en(bool set);

/*gets and sets minimum  step  buffer  size.*/
uint8_t dof6_get_min_step_buf();

int8_t  dof6_set_min_step_buf(uint8_t steptime);

////////////////////////////////////////////////////////////////////////////////
//CMD//


/*gets or sets command*/
uint8_t  dof6_get_cmd();

void  dof6_set_cmd(uint8_t cmd);

void dof6_sensor_config (uint8_t accel_state, uint8_t gyro_state);


#ifdef __cplusplus
} // extern "C"
#endif

#endif

/*** End of File **************************************************************/