#include <built_in.h>
#include "resources.h"
#include "6dof_hal.h"
#include "6dof_hw.h"

void Auxiliary_Code(void);
void Set_Index(unsigned short index);
void Write_Command(unsigned short cmd);
void Write_Data(unsigned int _data);

void Auxiliary_Code() {
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

void Set_Index(unsigned short index) {
  TFT_RS = 0;
  asm nop;
  TFT_DataPort = index;
  asm nop; asm nop;
  Auxiliary_Code();
}

void Write_Command(unsigned short cmd) {
  TFT_RS = 1;
  asm nop;
  TFT_DataPort = cmd;
  asm nop; asm nop;
  Auxiliary_Code();
}

void Write_Data(unsigned int _data) {
  TFT_RS = 1;
  asm nop;
  TFT_DataPort = Hi(_data);
  asm nop; asm nop;
  Auxiliary_Code();
  asm nop;
  TFT_DataPort = Lo(_data);
  asm nop; asm nop;
  Auxiliary_Code();
}

uint8_t txt1[20];
float acc_x,acc_y,acc_z,gyro_x,gyro_y,gyro_z;

static void Display_Init() {
    TFT_Set_Active(Set_Index, Write_Command, Write_Data);
    TFT_Init_ILI9341_8bit(320, 240);
    TFT_BLED = 1;
    TFT_FILL_SCREEN(CL_WHITE);
    
    TFT_Set_Pen(CL_BLACK, 1);
    TFT_Line(20, 220, 300, 220);
    TFT_Line(20,  46, 300,  46);
    TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
    TFT_Write_Text("6DOF IMU 2  Click  Board  Demo", 20, 14);
    TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
    TFT_Write_Text("EasyMx PRO v7 for STM32", 19, 223);
    TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
    TFT_Write_Text("www.mikroe.com", 200, 223);
    TFT_Set_Pen(CL_WHITE, 1);
    TFT_Set_Brush(1,CL_WHITE,0,0,0,0);
    
    TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);

    TFT_Write_Text("acc x :", 30, 60);
    TFT_Write_Text("acc y :", 30, 120);
    TFT_Write_Text("acc z :", 30, 180);
    TFT_Write_Text("gyr x :", 210, 60);
    TFT_Write_Text("gyr y :", 210, 120);
    TFT_Write_Text("gyr z :", 210, 180);

}

void display_data()
{

      acc_x=dof6_get_acc_x();
      acc_y=dof6_get_acc_y();
      acc_z=dof6_get_acc_z();
      gyro_x=dof6_get_gyr_x();
      gyro_y=dof6_get_gyr_y();
      gyro_z=dof6_get_gyr_z();

      sprintf(txt1, "%.2f", acc_x);
      TFT_Rectangle(30,80,80,100);
      TFT_Write_Text(txt1,30,80);

      sprintf(txt1, "%.2f", acc_y);
      TFT_Rectangle(30,140, 80, 160);
      TFT_Write_Text(txt1,30,140);

      sprintf(txt1, "%.2f", acc_z);
      TFT_Rectangle(30,200, 80, 210);
      TFT_Write_Text(txt1,30,200);

      sprintf(txt1, "%.2f", gyro_x);
      TFT_Rectangle(210,80, 260, 100);
      TFT_Write_Text(txt1,210,80);

      sprintf(txt1, "%.2f", gyro_y);
      TFT_Rectangle(210,140, 260, 160);
      TFT_Write_Text(txt1,210,140);

      sprintf(txt1, "%.2f", gyro_z);
      TFT_Rectangle(210,200, 260, 210);
      TFT_Write_Text(txt1,210,200);

}

void main() {


        Display_Init();
        I2CM1_Init(_I2CM_SPEED_MODE_STANDARD,_I2CM_SWAP_DISABLE);
        dof6_hal_init(BMI160_I2C_ADDRESS );
        dof6_sensor_config(accel_normal , gyro_normal);

        while (1)
        {
           display_data();
           Delay_ms(50);
        }
}